function [ret,x0,str,ts,xts]=regulfin(t,x,u,flag);
%REGULFIN	is the M-file description of the SIMULINK system named REGULFIN.
%	The block-diagram can be displayed by typing: REGULFIN.
%
%	SYS=REGULFIN(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGULFIN to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGULFIN with a FLAG of zero:
%	[SIZES]=REGULFIN([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[0,40,1264,964])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Outport',[sys,'/','Outport1'])
set_param([sys,'/','Outport1'],...
		'hide name',0,...
		'position',[1210,424,1230,446])

add_block('built-in/Inport',[sys,'/','in_1'])
set_param([sys,'/','in_1'],...
		'position',[25,445,45,465])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[-10,155,1285,835])

add_block('built-in/Note',[sys,'/','Subsystem/pqrQ '])
set_param([sys,'/','Subsystem/pqrQ '],...
		'position',[110,281,115,286])


%     Subsystem  'Subsystem/Rtroaction quaternion'.

new_system([sys,'/','Subsystem/Rtroaction quaternion'])
set_param([sys,'/','Subsystem/Rtroaction quaternion'],'Location',[174,67,1111,492])

add_block('built-in/Note',[sys,'/',['Subsystem/Rtroaction quaternion/Sortie B',13,'axes satellite1']])
set_param([sys,'/',['Subsystem/Rtroaction quaternion/Sortie B',13,'axes satellite1']],...
		'hide name',0,...
		'position',[310,155,315,160])

add_block('built-in/Demux',[sys,'/','Subsystem/Rtroaction quaternion/Demux1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Demux1'],...
		'hide name',0,...
		'outputs','[1 1 1 4]',...
		'position',[215,64,275,281])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/p '])
set_param([sys,'/','Subsystem/Rtroaction quaternion/p '],...
		'hide name',0,...
		'position',[295,70,300,75])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/r '])
set_param([sys,'/','Subsystem/Rtroaction quaternion/r '],...
		'hide name',0,...
		'position',[295,175,300,180])

add_block('built-in/Inport',[sys,'/','Subsystem/Rtroaction quaternion/in_1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/in_1'],...
		'hide name',0,...
		'position',[140,165,160,185])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/pqrQ'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/pqrQ'],...
		'hide name',0,...
		'position',[150,140,155,145])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/q inutile'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/q inutile'],...
		'hide name',0,...
		'position',[310,130,315,135])

add_block('built-in/Gain',[sys,'/','Subsystem/Rtroaction quaternion/Gain3'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Gain3'],...
		'hide name',0,...
		'Gain','K_lacet',...
		'position',[295,187,320,213])

add_block('built-in/Gain',[sys,'/','Subsystem/Rtroaction quaternion/Gain2'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Gain2'],...
		'hide name',0,...
		'Gain','K_roulis',...
		'position',[300,77,325,103])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/K_roulis'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/K_roulis'],...
		'position',[310,50,315,55])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/K_lacet'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/K_lacet'],...
		'position',[300,160,305,165])

add_block('built-in/Sum',[sys,'/','Subsystem/Rtroaction quaternion/Sum1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Sum1'],...
		'hide name',0,...
		'position',[595,174,630,241])

add_block('built-in/Gain',[sys,'/','Subsystem/Rtroaction quaternion/Gain4'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Gain4'],...
		'hide name',0,...
		'Gain','K_Q1',...
		'position',[545,212,570,238])

add_block('built-in/Gain',[sys,'/','Subsystem/Rtroaction quaternion/Gain5'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Gain5'],...
		'hide name',0,...
		'Gain','K_Q3',...
		'position',[565,337,590,363])

add_block('built-in/Sum',[sys,'/','Subsystem/Rtroaction quaternion/Sum2'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Sum2'],...
		'hide name',0,...
		'position',[605,299,640,366])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/Composante e1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Composante e1'],...
		'hide name',0,...
		'position',[735,170,740,175])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/Composante e3'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Composante e3'],...
		'hide name',0,...
		'position',[725,295,730,300])

add_block('built-in/Outport',[sys,'/','Subsystem/Rtroaction quaternion/out_5'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/out_5'],...
		'hide name',0,...
		'Port','2',...
		'position',[680,325,700,345])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/K_Q1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/K_Q1'],...
		'position',[550,185,555,190])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/K_Q3'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/K_Q3'],...
		'position',[580,365,585,370])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/Sortie de e3'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Sortie de e3'],...
		'position',[750,320,755,325])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/q2 inutile'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/q2 inutile'],...
		'position',[435,230,440,235])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/q1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/q1'],...
		'position',[405,205,410,210])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/q4 inutile'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/q4 inutile'],...
		'position',[410,270,415,275])

add_block('built-in/Demux',[sys,'/','Subsystem/Rtroaction quaternion/Demux2'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Demux2'],...
		'hide name',0,...
		'position',[330,215,375,295])

add_block('built-in/Note',[sys,'/','Subsystem/Rtroaction quaternion/Sortie de e1'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/Sortie de e1'],...
		'position',[745,195,750,200])

add_block('built-in/Outport',[sys,'/','Subsystem/Rtroaction quaternion/out_2'])
set_param([sys,'/','Subsystem/Rtroaction quaternion/out_2'],...
		'hide name',0,...
		'position',[675,200,695,220])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[280,90;295,90])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[280,200;290,200])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[325,200;490,200;490,315;600,315])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[280,255;325,255])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[330,90;400,90;400,190;590,190])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[380,225;540,225])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[575,225;590,225])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[595,350;600,350])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[380,265;450,265;450,350;560,350])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[165,175;210,175])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[635,210;670,210])
add_line([sys,'/','Subsystem/Rtroaction quaternion'],[645,335;675,335])
set_param([sys,'/','Subsystem/Rtroaction quaternion'],...
		'Mask Display','Calcul de e1 et e3\navec le quaternion')


%     Finished composite block 'Subsystem/Rtroaction quaternion'.

set_param([sys,'/','Subsystem/Rtroaction quaternion'],...
		'position',[125,311,310,389])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Couple magntique',13,'1']])
set_param([sys,'/',['Subsystem/Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','u/norm(u)',...
		'Output Width','3',...
		'position',[350,431,440,469])

add_block('built-in/Note',[sys,'/','Subsystem/B'])
set_param([sys,'/','Subsystem/B'],...
		'position',[340,426,345,431])

add_block('built-in/Note',[sys,'/','Subsystem/e(2)'])
set_param([sys,'/','Subsystem/e(2)'],...
		'position',[340,261,345,266])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace4'])
set_param([sys,'/','Subsystem/To Workspace4'],...
		'hide name',0,...
		'mat-name','e',...
		'buffer','points_trace',...
		'position',[455,269,490,291])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux5'])
set_param([sys,'/','Subsystem/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[395,320,425,380])

add_block('built-in/Note',[sys,'/','Subsystem/e(1)'])
set_param([sys,'/','Subsystem/e(1)'],...
		'position',[375,306,380,311])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum'])
set_param([sys,'/','Subsystem/Sum'],...
		'inputs','+++',...
		'position',[1100,146,1125,514])

add_block('built-in/Note',[sys,'/','Subsystem/Couple gnral'])
set_param([sys,'/','Subsystem/Couple gnral'],...
		'position',[1175,351,1180,356])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace6'])
set_param([sys,'/','Subsystem/To Workspace6'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Couple_general',...
		'buffer','points_trace',...
		'position',[1005,104,1125,126])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'Gain','K_CPL_MGN_NUL',...
		'position',[1030,437,1055,463])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace3'])
set_param([sys,'/','Subsystem/To Workspace3'],...
		'hide name',0,...
		'mat-name','Couple_magnetique',...
		'buffer','points_trace',...
		'position',[1105,549,1225,571])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Couple magntique'])
set_param([sys,'/','Subsystem/Couple magntique'],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[920,431,1010,469])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace2'])
set_param([sys,'/','Subsystem/To Workspace2'],...
		'hide name',0,...
		'mat-name','moment_magnetique',...
		'buffer','points_trace',...
		'position',[880,304,1020,326])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux6'])
set_param([sys,'/','Subsystem/Mux6'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[850,363,880,567])

add_block('built-in/Note',[sys,'/',['Subsystem/vecteur ',13,'B//||B||']])
set_param([sys,'/',['Subsystem/vecteur ',13,'B//||B||']],...
		'position',[465,411,470,416])

add_block('built-in/Note',[sys,'/','Subsystem/vecteur e'])
set_param([sys,'/','Subsystem/vecteur e'],...
		'position',[460,351,465,356])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux4'])
set_param([sys,'/','Subsystem/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[490,299,530,501])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Moment ',13,'magntique',13,'brut']])
set_param([sys,'/',['Subsystem/Moment ',13,'magntique',13,'brut']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[545,381,635,419])

add_block('built-in/Note',[sys,'/',['Subsystem/Moment',13,'magntique']])
set_param([sys,'/',['Subsystem/Moment',13,'magntique']],...
		'position',[585,336,590,341])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux7'])
set_param([sys,'/','Subsystem/Mux7'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[665,389,700,436])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Saturation'])
set_param([sys,'/','Subsystem/Saturation'],...
		'MATLAB Fcn','magn_sat(u)',...
		'Output Width','3',...
		'position',[715,396,805,434])

add_block('built-in/Note',[sys,'/',['Subsystem/Couple action',13,'roue sur satellite']])
set_param([sys,'/',['Subsystem/Couple action',13,'roue sur satellite']],...
		'position',[1010,166,1015,171])

add_block('built-in/Note',[sys,'/','Subsystem/Sortie 1'])
set_param([sys,'/','Subsystem/Sortie 1'],...
		'position',[355,186,360,191])

add_block('built-in/Note',[sys,'/',['Subsystem/NB : Sur le satellite,il agit l''oppos du couple roue']])
set_param([sys,'/',['Subsystem/NB : Sur le satellite,il agit l''oppos du couple roue']],...
		'position',[550,186,555,191])

add_block('built-in/Note',[sys,'/','Subsystem/Sortie 2 :'])
set_param([sys,'/','Subsystem/Sortie 2 :'],...
		'position',[355,211,360,216])

add_block('built-in/Note',[sys,'/','Subsystem/NB : Couple  gyroscopique  action roue sur satellite'])
set_param([sys,'/','Subsystem/NB : Couple  gyroscopique  action roue sur satellite'],...
		'position',[535,211,540,216])


%     Subsystem  'Subsystem/FONCTION ROUE'.

new_system([sys,'/','Subsystem/FONCTION ROUE'])
set_param([sys,'/','Subsystem/FONCTION ROUE'],'Location',[4,44,1238,765])

add_block('built-in/Demux',[sys,'/','Subsystem/FONCTION ROUE/Demux'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Demux'],...
		'outputs','[1 1 1 4]',...
		'position',[80,135,125,225])

add_block('built-in/Integrator',[sys,'/','Subsystem/FONCTION ROUE/Integrator'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Integrator'],...
		'Initial',' omega_roue_ref',...
		'position',[615,324,670,356])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Vitesse',13,'roue']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Vitesse',13,'roue']],...
		'position',[640,285,645,290])

add_block('built-in/Sum',[sys,'/','Subsystem/FONCTION ROUE/Sum'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Sum'],...
		'inputs','+-',...
		'position',[780,302,820,458])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/h'])
set_param([sys,'/','Subsystem/FONCTION ROUE/h'],...
		'position',[765,310,770,315])


%     Subsystem  ['Subsystem/FONCTION ROUE/Inner',13,'Product1'].

new_system([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/Product']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],[40,100;60,70])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],[150,65;180,65])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Subsystem/FONCTION ROUE/Inner',13,'Product1'].

set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product1']],...
		'position',[825,227,850,258])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/r'])
set_param([sys,'/','Subsystem/FONCTION ROUE/r'],...
		'position',[770,95,775,100])


%     Subsystem  ['Subsystem/FONCTION ROUE/Inner',13,'Product'].

new_system([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/Product']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/Sum']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/out_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/in_2']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/in_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Subsystem/FONCTION ROUE/Inner',13,'Product'].

set_param([sys,'/',['Subsystem/FONCTION ROUE/Inner',13,'Product']],...
		'position',[825,107,850,138])

add_block('built-in/Mux',[sys,'/','Subsystem/FONCTION ROUE/Mux1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Mux1'],...
		'inputs','3',...
		'position',[905,130,945,250])

add_block('built-in/Constant',[sys,'/','Subsystem/FONCTION ROUE/Constant3'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Constant3'],...
		'Value','0',...
		'position',[815,176,860,204])

add_block('built-in/Outport',[sys,'/','Subsystem/FONCTION ROUE/out_1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/out_1'],...
		'position',[1035,605,1055,625])

add_block('built-in/Constant',[sys,'/','Subsystem/FONCTION ROUE/Constant1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Constant1'],...
		'Value','0',...
		'position',[685,566,730,594])

add_block('built-in/Mux',[sys,'/','Subsystem/FONCTION ROUE/Mux'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Mux'],...
		'inputs','3',...
		'position',[770,561,810,669])

add_block('built-in/Constant',[sys,'/','Subsystem/FONCTION ROUE/Constant2'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Constant2'],...
		'Value','0',...
		'position',[685,636,730,664])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/Sortie de e(2)'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Sortie de e(2)'],...
		'position',[965,330,970,335])

add_block('built-in/To Workspace',[sys,'/','Subsystem/FONCTION ROUE/To Workspace1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/To Workspace1'],...
		'hide name',0,...
		'mat-name','omega_roue',...
		'buffer','points_trace',...
		'position',[690,495,770,515])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Sortie vitesse',13,'roue (rd//s)']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Sortie vitesse',13,'roue (rd//s)']],...
		'position',[820,490,825,495])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Couple action',13,'roue//satellite',13,'vectoriel']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Couple action',13,'roue//satellite',13,'vectoriel']],...
		'position',[885,645,890,650])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']],...
		'position',[1025,115,1030,120])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/q'])
set_param([sys,'/','Subsystem/FONCTION ROUE/q'],...
		'position',[140,160,145,165])

add_block('built-in/Outport',[sys,'/','Subsystem/FONCTION ROUE/out 2'])
set_param([sys,'/','Subsystem/FONCTION ROUE/out 2'],...
		'Port','2',...
		'position',[1075,177,1100,203])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain6'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain6'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[570,138,625,162])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/Vitesse tangage'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Vitesse tangage'],...
		'position',[205,145,210,150])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/pqrQ'])
set_param([sys,'/','Subsystem/FONCTION ROUE/pqrQ'],...
		'position',[55,130,60,135])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain2'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain2'],...
		'hide name',0,...
		'Gain','K_tangage',...
		'position',[895,364,940,396])

add_block('built-in/Inport',[sys,'/','Subsystem/FONCTION ROUE/in_1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/in_1'],...
		'position',[15,170,35,190])

add_block('built-in/Constant',[sys,'/','Subsystem/FONCTION ROUE/Constant'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Constant'],...
		'Value','h_ref',...
		'position',[710,406,755,434])

add_block('built-in/Outport',[sys,'/','Subsystem/FONCTION ROUE/out_3_'])
set_param([sys,'/','Subsystem/FONCTION ROUE/out_3_'],...
		'Port','3',...
		'position',[1090,370,1110,390])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/Couple gyroscopique '])
set_param([sys,'/','Subsystem/FONCTION ROUE/Couple gyroscopique '],...
		'position',[375,120,380,125])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Couple roue//satellite',13,'scalaire sur',13,'tangage',13,'(Satellite//roue)']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Couple roue//satellite',13,'scalaire sur',13,'tangage',13,'(Satellite//roue)']],...
		'position',[1015,485,1020,490])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/FONCTION ROUE/Couple magntique',13,'1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','u(2)',...
		'Output Width','1',...
		'position',[160,281,250,319])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain4'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain4'],...
		'hide name',0,...
		'Gain','KP_roue',...
		'position',[280,287,305,313])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain5'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain5'],...
		'hide name',0,...
		'Gain','KD_roue',...
		'position',[285,367,310,393])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/tangage'])
set_param([sys,'/','Subsystem/FONCTION ROUE/tangage'],...
		'hide name',0,...
		'position',[295,335,300,340])

add_block('built-in/Sum',[sys,'/','Subsystem/FONCTION ROUE/Sum1'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Sum1'],...
		'hide name',0,...
		'position',[335,262,375,418])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Couple action',13,'satellite//roue']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Couple action',13,'satellite//roue']],...
		'position',[520,260,525,265])

add_block('built-in/To Workspace',[sys,'/','Subsystem/FONCTION ROUE/To Workspace6'])
set_param([sys,'/','Subsystem/FONCTION ROUE/To Workspace6'],...
		'hide name',0,...
		'mat-name','Couple_roue',...
		'buffer','points_trace',...
		'position',[985,559,1065,581])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/Satellite//roue'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Satellite//roue'],...
		'position',[595,445,600,450])


%     Subsystem  ['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement'].

new_system([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],'Location',[263,571,960,781])

add_block('built-in/Product',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/Product']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/Product']],...
		'position',[210,36,245,129])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/MATLAB Fcn1']],...
		'MATLAB Fcn','(u>5)+(u<=5)*u/5',...
		'Output Width','1',...
		'position',[115,88,175,122])

add_block('built-in/Clock',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/Clock']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/Clock']],...
		'position',[40,95,60,115])

add_block('built-in/Inport',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/in_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/in_1']],...
		'position',[140,30,160,50])

add_block('built-in/Outport',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/out_1']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/out_1']],...
		'position',[365,145,385,165])

add_block('built-in/To Workspace',[sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/To Workspace6']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement/To Workspace6']],...
		'hide name',0,...
		'mat-name','couple_test',...
		'buffer','points_trace',...
		'position',[365,74,445,96])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],[180,105;205,105])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],[65,105;110,105])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],[165,40;165,60;205,60])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],[250,85;310,85;310,155;360,155])
add_line([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],[310,85;360,85])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],...
		'Mask Display','Regulateur de\nmonte progressive\ndu couple roue')


%     Finished composite block ['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement'].

set_param([sys,'/',['Subsystem/FONCTION ROUE/Rgulateur',13,'au lancement']],...
		'position',[405,313,530,367])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain'],...
		'Gain','1/Jroue',...
		'position',[565,327,590,353])

add_block('built-in/Note',[sys,'/',['Subsystem/FONCTION ROUE/Version fonctionnant avec la vitesse angulaire q',13,' et la deuxime composante du quaternion']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Version fonctionnant avec la vitesse angulaire q',13,' et la deuxime composante du quaternion']],...
		'Font Name','Arial Narrow',...
		'Font Size',20,...
		'position',[600,15,605,20])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/KD_roue'])
set_param([sys,'/','Subsystem/FONCTION ROUE/KD_roue'],...
		'position',[295,390,300,395])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/KP_roue'])
set_param([sys,'/','Subsystem/FONCTION ROUE/KP_roue'],...
		'position',[300,265,305,270])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/1//Jroue'])
set_param([sys,'/','Subsystem/FONCTION ROUE/1//Jroue'],...
		'position',[575,370,580,375])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/r '])
set_param([sys,'/','Subsystem/FONCTION ROUE/r '],...
		'position',[295,165,300,170])

add_block('built-in/Note',[sys,'/','Subsystem/FONCTION ROUE/p'])
set_param([sys,'/','Subsystem/FONCTION ROUE/p'],...
		'position',[475,130,480,135])

add_block('built-in/Gain',[sys,'/',['Subsystem/FONCTION ROUE/Moment',13,'Inertie']])
set_param([sys,'/',['Subsystem/FONCTION ROUE/Moment',13,'Inertie']],...
		'Gain','Jroue',...
		'position',[715,327,740,353])

add_block('built-in/Gain',[sys,'/','Subsystem/FONCTION ROUE/Gain3'])
set_param([sys,'/','Subsystem/FONCTION ROUE/Gain3'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[855,603,910,627])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[825,380;890,380])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[760,420;775,420])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[745,340;775,340])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[675,340;710,340])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[595,340;610,340])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[945,380;1085,380])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[735,580;765,580])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[735,650;765,650])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[675,340;685,505])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[40,180;75,180])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[745,340;745,130;820,130])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[745,250;820,250])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[865,190;900,190])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[855,245;885,245;885,230;900,230])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[855,125;880,125;880,150;900,150])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[815,615;850,615])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[915,615;1030,615])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[315,380;330,380])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[310,300;330,300])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[950,190;1070,190])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[630,150;710,150;710,235;820,235])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[130,150;565,150])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[130,190;445,190;445,115;820,115])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[130,170;265,170;265,380;280,380])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[255,300;275,300])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[130,210;145,210;155,300])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[380,340;400,340])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[535,340;560,340])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[535,340;535,615;765,615])
add_line([sys,'/','Subsystem/FONCTION ROUE'],[945,615;945,570;980,570])
set_param([sys,'/','Subsystem/FONCTION ROUE'],...
		'Mask Display','FONCTIONNEMENT\nDE LA ROUE\nET SORTIE DE e(2)')


%     Finished composite block 'Subsystem/FONCTION ROUE'.

set_param([sys,'/','Subsystem/FONCTION ROUE'],...
		'position',[125,194,325,276])

add_block('built-in/Note',[sys,'/','Subsystem/e(3)'])
set_param([sys,'/','Subsystem/e(3)'],...
		'position',[375,376,380,381])


%     Subsystem  ['Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[59,535,1014,1004])

add_block('built-in/Mux',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Inport',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Outport',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[885,150,905,170])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Axes satellite']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Axes satellite']],...
		'position',[875,110,880,115])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[880,85,885,90])
add_line([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;880,160])
add_line([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[120,412,320,488])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[1155,320,1175,340])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[75,340,95,360])
add_line([sys,'/','Subsystem'],[100,350;120,350])
add_line([sys,'/','Subsystem'],[100,350;80,350;80,450;115,450])
add_line([sys,'/','Subsystem'],[100,350;80,350;80,235;120,235])
add_line([sys,'/','Subsystem'],[315,370;390,370])
add_line([sys,'/','Subsystem'],[315,330;390,330])
add_line([sys,'/','Subsystem'],[705,415;710,415])
add_line([sys,'/','Subsystem'],[325,450;325,515;845,515])
add_line([sys,'/','Subsystem'],[645,515;645,425;660,425])
add_line([sys,'/','Subsystem'],[640,400;660,400])
add_line([sys,'/','Subsystem'],[810,415;845,415])
add_line([sys,'/','Subsystem'],[820,415;820,315;875,315])
add_line([sys,'/','Subsystem'],[1060,450;1095,450])
add_line([sys,'/','Subsystem'],[1080,450;1080,560;1100,560])
add_line([sys,'/','Subsystem'],[330,235;685,235;685,261;1035,261;1035,330;1095,330])
add_line([sys,'/','Subsystem'],[1130,330;1150,330])
add_line([sys,'/','Subsystem'],[1140,330;1155,330;1155,115;1130,115])
add_line([sys,'/','Subsystem'],[330,210;1095,210])
add_line([sys,'/','Subsystem'],[1015,450;1025,450])
add_line([sys,'/','Subsystem'],[885,465;915,450])
add_line([sys,'/','Subsystem'],[325,450;345,450])
add_line([sys,'/','Subsystem'],[445,450;485,450])
add_line([sys,'/','Subsystem'],[330,260;360,260;360,350;390,350])
add_line([sys,'/','Subsystem'],[430,350;485,350])
add_line([sys,'/','Subsystem'],[440,350;450,280])
add_line([sys,'/','Subsystem'],[535,400;540,400])
set_param([sys,'/','Subsystem'],...
		'Mask Display','REGULATION\nFINALE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'position',[410,411,670,509])
add_line(sys,[675,460;1115,460;1115,435;1205,435])
add_line(sys,[50,455;405,460])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
