function [ret,x0,str,ts,xts]=sca_fin3(t,x,u,flag);
%SCA_FIN3	is the M-file description of the SIMULINK system named SCA_FIN3.
%	The block-diagram can be displayed by typing: SCA_FIN3.
%
%	SYS=SCA_FIN3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCA_FIN3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCA_FIN3 with a FLAG of zero:
%	[SIZES]=SCA_FIN3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,79,1268,1003])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Adams/Gear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '60000')
set_param(sys,'Min step size', '2')
set_param(sys,'Max step size', '2')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[625,395,630,400])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[630,255,635,260])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]*0+etat_init_fin',...
		'position',[735,324,835,376])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[610,204,670,491])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[235,368,450,472])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[525,420,530,425])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[535,240,540,245])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[480,485,485,490])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[295,510,300,515])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[705,505,710,510])

add_block('built-in/Note',[sys,'/','STABILISATION FINE AUTOUR DU POINTAGE NADIR'])
set_param([sys,'/','STABILISATION FINE AUTOUR DU POINTAGE NADIR'],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[658,10,663,15])

add_block('built-in/Note',[sys,'/',['REGULATION DE STEYN ( Applique  SNAP-1 Nanosatellite )',13,'']])
set_param([sys,'/',['REGULATION DE STEYN ( Applique  SNAP-1 Nanosatellite )',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[630,45,635,50])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[820,205,825,210])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,44,1012,680])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=cyan\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[905,485,1135,571])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance stn3dat.m']])
set_param([sys,'/',['L''initialisation',13,' lance stn3dat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1005,435,1010,440])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[465,540,470,545])


%     Subsystem  'Extras21'.

new_system([sys,'/','Extras21'])
set_param([sys,'/','Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras21'],...
		'Mask Display','Couple total\n\nde commande (Nm )',...
		'Mask Dialogue','eval(''plot(temps(100:length(q)),Couple_general(100:length(q)));grid;figure(gcf)'')')


%     Finished composite block 'Extras21'.

set_param([sys,'/','Extras21'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,665,785,731])


%     Subsystem  'Extras26'.

new_system([sys,'/','Extras26'])
set_param([sys,'/','Extras26'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras26'],...
		'Mask Display','Couple perturbateur\n\n (Nm )',...
		'Mask Dialogue','eval(''plot(temps(100:length(q)),couple_perturb(100:length(q)));grid;figure(gcf)'')')


%     Finished composite block 'Extras26'.

set_param([sys,'/','Extras26'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,735,785,801])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Dpointages\nangulaires entre\n X Y Z et x y z\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,depointages);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1035,740,1240,811])


%     Subsystem  'Extras23'.

new_system([sys,'/','Extras23'])
set_param([sys,'/','Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras23'],...
		'Mask Display','Voir la courbe\n\nvecteur e ( Am)',...
		'Mask Dialogue','eval(''plot(temps,e);grid;figure(gcf)'')')


%     Finished composite block 'Extras23'.

set_param([sys,'/','Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[795,740,1015,806])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Voir la courbe\n\ncouple magntique (Nm)',...
		'Mask Dialogue','eval(''plot(temps,Couple_magnetique);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[795,670,1010,736])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nsatellite/XYZ (/s)',...
		'Mask Dialogue','eval(''plot(temps,omega_quat);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1035,665,1245,726])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir la courbe\n\nmoment magntique (Am)',...
		'Mask Dialogue','eval(''plot(temps,moment_magnetique);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[790,590,1005,656])


%     Subsystem  'Extras24'.

new_system([sys,'/','Extras24'])
set_param([sys,'/','Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras24'],...
		'Mask Display','Voir la courbe\n\ncouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps(100:length(q)),Couple_roue(100:length(q)),''''y'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras24'.

set_param([sys,'/','Extras24'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,590,785,656])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMz',...
		'Mask Dialogue','eval(''plot(temps,moment_magnetique(:,3));grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,735,560,796])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMy',...
		'Mask Dialogue','eval(''plot(temps,moment_magnetique(:,2));grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,665,560,726])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMx',...
		'Mask Dialogue','eval(''plot(temps,moment_magnetique(:,1));grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,590,560,651])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Angles de Cardan\n\n (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[80,590,280,656])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Vitesses angulaires\nabsolues\np, q, r (degrs/s)',...
		'Mask Dialogue','eval(''plot(temps,p,''''y'''',temps,q,''''c'''',temps,r,''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[80,670,275,726])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' ''Q''']])
set_param([sys,'/',['p'' q'' r'' ''Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[775,255,780,260])


%     Subsystem  'Extras22'.

new_system([sys,'/','Extras22'])
set_param([sys,'/','Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras22'],...
		'Mask Display','Voir la courbe\n\nVitesse roue (t/mn)',...
		'Mask Dialogue','eval(''plot(temps,omega_roue*30/pi);grid;figure(gcf)'')')


%     Finished composite block 'Extras22'.

set_param([sys,'/','Extras22'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1035,590,1250,656])


%     Subsystem  'Extras25'.

new_system([sys,'/','Extras25'])
set_param([sys,'/','Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras25'],...
		'Mask Display','Dpointage\nangulaires entre\n  Z et z en degrs\n CAPITAL POUR\nLA MISSION',...
		'Mask Dialogue','eval(''plot(temps,depointages(:,3));grid;figure(gcf)'')')


%     Finished composite block 'Extras25'.

set_param([sys,'/','Extras25'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1030,820,1240,921])


%     Subsystem  'Extras27'.

new_system([sys,'/','Extras27'])
set_param([sys,'/','Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras27'],...
		'Mask Display','Couple\n gyroscopique (Nm )',...
		'Mask Dialogue','eval(''plot(temps(100:length(q)),couple_gyroscopique(100:length(q)));grid;figure(gcf)'')')


%     Finished composite block 'Extras27'.

set_param([sys,'/','Extras27'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[85,735,275,801])


%     Subsystem  'Sorties et stop'.

new_system([sys,'/','Sorties et stop'])
set_param([sys,'/','Sorties et stop'],'Location',[4,80,1268,1004])

add_block('built-in/Inport',[sys,'/','Sorties et stop/in_1'])
set_param([sys,'/','Sorties et stop/in_1'],...
		'position',[165,480,185,500])

add_block('built-in/Demux',[sys,'/','Sorties et stop/Demux'])
set_param([sys,'/','Sorties et stop/Demux'],...
		'outputs','[3 4]',...
		'position',[270,404,320,571])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties et stop/MATLAB Fcn1'])
set_param([sys,'/','Sorties et stop/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[500,513,560,547])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace14'])
set_param([sys,'/','Sorties et stop/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[765,555,835,575])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace12'])
set_param([sys,'/','Sorties et stop/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[765,485,835,505])

add_block('built-in/Demux',[sys,'/','Sorties et stop/Demux2'])
set_param([sys,'/','Sorties et stop/Demux2'],...
		'outputs','3',...
		'position',[660,478,705,582])

add_block('built-in/Note',[sys,'/','Sorties et stop/Energie'])
set_param([sys,'/','Sorties et stop/Energie'],...
		'position',[685,455,690,460])

add_block('built-in/Note',[sys,'/','Sorties et stop/Quaternion Q'])
set_param([sys,'/','Sorties et stop/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[400,500,405,505])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace7'])
set_param([sys,'/','Sorties et stop/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[650,435,720,455])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties et stop/MATLAB Fcn3'])
set_param([sys,'/','Sorties et stop/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[545,426,625,464])

add_block('built-in/Fcn',[sys,'/','Sorties et stop/Fcn'])
set_param([sys,'/','Sorties et stop/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[520,390,560,410])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace9'])
set_param([sys,'/','Sorties et stop/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusr2',...
		'buffer','points_trace',...
		'position',[605,390,675,410])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace13'])
set_param([sys,'/','Sorties et stop/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[765,520,835,540])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace8'])
set_param([sys,'/','Sorties et stop/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[765,590,835,610])

add_block('built-in/Clock',[sys,'/','Sorties et stop/Clock'])
set_param([sys,'/','Sorties et stop/Clock'],...
		'position',[705,590,725,610])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace10'])
set_param([sys,'/','Sorties et stop/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[600,337,700,363])

add_block('built-in/Demux',[sys,'/','Sorties et stop/Demux3'])
set_param([sys,'/','Sorties et stop/Demux3'],...
		'outputs','3',...
		'position',[410,223,455,327])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[580,517,605,543])

add_block('built-in/Note',[sys,'/','Sorties et stop/Vrification  rotation transversale'])
set_param([sys,'/','Sorties et stop/Vrification  rotation transversale'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[605,360,610,365])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace15'])
set_param([sys,'/','Sorties et stop/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[590,230,660,250])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace17'])
set_param([sys,'/','Sorties et stop/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[595,300,665,320])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs1']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs1']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[520,227,545,253])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs2']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs2']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[520,262,545,288])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs3']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs3']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[520,297,545,323])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']])
set_param([sys,'/',['Sorties et stop/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']],...
		'position',[760,230,765,235])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace16'])
set_param([sys,'/','Sorties et stop/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[590,265,660,285])


%     Subsystem  'Sorties et stop/Rotation // axes orbitaux'.

new_system([sys,'/','Sorties et stop/Rotation // axes orbitaux'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux'],'Location',[228,316,1185,966])

add_block('built-in/Outport',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Outport'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Outport'],...
		'hide name',0,...
		'position',[830,265,850,285])

add_block('built-in/Note',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Drive de Q'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[445,300,450,305])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties et stop/Rotation // axes orbitaux/MATLAB Fcn4'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[625,256,705,294])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/Rotation // axes orbitaux/To Workspace5'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[375,197,480,233])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Rotation // axes orbitaux/Q''']])
set_param([sys,'/',['Sorties et stop/Rotation // axes orbitaux/Q''']],...
		'position',[520,305,525,310])

add_block('built-in/Note',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Q'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Q'],...
		'position',[515,225,520,230])

add_block('built-in/Demux',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Demux1'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Demux1'],...
		'outputs','[3 4]',...
		'position',[280,174,330,341])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Rotation // axes orbitaux/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Sorties et stop/Rotation // axes orbitaux/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[755,262,780,288])

add_block('built-in/Mux',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Mux'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Mux'],...
		'inputs','[4 4]',...
		'position',[545,226,580,324])

add_block('built-in/Inport',[sys,'/','Sorties et stop/Rotation // axes orbitaux/in_2'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/in_2'],...
		'Port','2',...
		'position',[155,250,175,270])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Rotation // axes orbitaux/Entre de la',13,'drive du vecteur d''tat']])
set_param([sys,'/',['Sorties et stop/Rotation // axes orbitaux/Entre de la',13,'drive du vecteur d''tat']],...
		'position',[160,285,165,290])

add_block('built-in/Note',[sys,'/','Sorties et stop/Rotation // axes orbitaux/Entre de Q'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/Entre de Q'],...
		'position',[175,95,180,100])

add_block('built-in/Inport',[sys,'/','Sorties et stop/Rotation // axes orbitaux/in_1'])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux/in_1'],...
		'position',[155,130,175,150])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']])
set_param([sys,'/',['Sorties et stop/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['Sorties et stop/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']],...
		'position',[790,320,795,325])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[785,275;825,275])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[710,275;750,275])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[585,275;620,275])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[335,300;540,300])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[335,215;370,215])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[180,260;275,260])
add_line([sys,'/','Sorties et stop/Rotation // axes orbitaux'],[180,140;485,140;485,250;540,250])
set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux'],...
		'Mask Display','CALCUL DE LA VITESSE\nDE ROTATION\nEN AXES ORBITAUX')


%     Finished composite block 'Sorties et stop/Rotation // axes orbitaux'.

set_param([sys,'/','Sorties et stop/Rotation // axes orbitaux'],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[500,710,720,765])

add_block('built-in/Note',[sys,'/','Sorties et stop/Q'])
set_param([sys,'/','Sorties et stop/Q'],...
		'position',[450,700,455,705])

add_block('built-in/Inport',[sys,'/','Sorties et stop/in_2'])
set_param([sys,'/','Sorties et stop/in_2'],...
		'Port','2',...
		'position',[380,740,400,760])

add_block('built-in/MATLAB Fcn',[sys,'/',['Sorties et stop/fonction',13,'de calcul ',13,'des dpointages']])
set_param([sys,'/',['Sorties et stop/fonction',13,'de calcul ',13,'des dpointages']],...
		'MATLAB Fcn','depoint(u)',...
		'Output Width','3',...
		'Mask Display','depoint.m',...
		'position',[580,121,685,159])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Entre de ',13,'la drive du vecteur d''tat']])
set_param([sys,'/',['Sorties et stop/Entre de ',13,'la drive du vecteur d''tat']],...
		'position',[450,775,455,780])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Sortie des valeurs finales',13,'de pqrQ']])
set_param([sys,'/',['Sorties et stop/Sortie des valeurs finales',13,'de pqrQ']],...
		'position',[325,645,330,650])

add_block('built-in/To File',[sys,'/','Sorties et stop/To File'])
set_param([sys,'/','Sorties et stop/To File'],...
		'File name','InitFin0.mat',...
		'Matrix name','init_sca_fin0',...
		'position',[290,689,395,721])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace19'])
set_param([sys,'/','Sorties et stop/To Workspace19'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','init_sca_fin0',...
		'buffer','1',...
		'position',[260,600,400,650])

add_block('built-in/Note',[sys,'/','Sorties et stop/Angles en degrs'])
set_param([sys,'/','Sorties et stop/Angles en degrs'],...
		'position',[805,450,810,455])

add_block('built-in/Note',[sys,'/','Sorties et stop/Sorties 3 angles'])
set_param([sys,'/','Sorties et stop/Sorties 3 angles'],...
		'position',[825,665,830,670])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Entre de',13,'p q r Q']])
set_param([sys,'/',['Sorties et stop/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[160,430,165,435])

add_block('built-in/Note',[sys,'/',['Sorties et stop/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Sorties et stop/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[635,0,640,5])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace18'])
set_param([sys,'/','Sorties et stop/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','depointages',...
		'buffer','points_trace',...
		'position',[820,124,905,156])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs ']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs ']],...
		'Gain','180/pi',...
		'position',[725,127,750,153])

add_block('built-in/Gain',[sys,'/',['Sorties et stop/Conversion',13,'rd // degrs 1']])
set_param([sys,'/',['Sorties et stop/Conversion',13,'rd // degrs 1']],...
		'Gain','180/pi',...
		'position',[690,852,715,878])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties et stop/MATLAB Fcn5'])
set_param([sys,'/','Sorties et stop/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omeg_orb(u)',...
		'Output Width','3',...
		'position',[495,846,575,884])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Calcul direct de la rotation par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Sorties et stop/Calcul direct de la rotation par',13,'rapport aux axes orbitaux']],...
		'position',[285,862,290,867])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace11'])
set_param([sys,'/','Sorties et stop/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[840,724,925,756])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Vitesses angulaires',13,'par rapport au repre',13,'orbital',13,'en degrs//s']])
set_param([sys,'/',['Sorties et stop/Vitesses angulaires',13,'par rapport au repre',13,'orbital',13,'en degrs//s']],...
		'position',[1090,740,1095,745])

add_block('built-in/Outport',[sys,'/','Sorties et stop/Outport2'])
set_param([sys,'/','Sorties et stop/Outport2'],...
		'Port','3',...
		'position',[890,805,910,825])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace20'])
set_param([sys,'/','Sorties et stop/To Workspace20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat1',...
		'buffer','points_trace',...
		'position',[1030,849,1115,881])

add_block('built-in/Outport',[sys,'/','Sorties et stop/Outport'])
set_param([sys,'/','Sorties et stop/Outport'],...
		'position',[915,625,935,645])

add_block('built-in/Outport',[sys,'/','Sorties et stop/Outport1'])
set_param([sys,'/','Sorties et stop/Outport1'],...
		'Port','2',...
		'position',[935,105,955,125])

add_block('built-in/Note',[sys,'/',['Sorties et stop/Sortie des',13,'3 dpointages']])
set_param([sys,'/',['Sorties et stop/Sortie des',13,'3 dpointages']],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/',['Sorties et stop/dpointages et vitesses',13,'en degrs ou degrs//s']])
set_param([sys,'/',['Sorties et stop/dpointages et vitesses',13,'en degrs ou degrs//s']],...
		'BackGround',7,...
		'position',[1005,310,1010,315])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties et stop/on_off'])
set_param([sys,'/','Sorties et stop/on_off'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','on_off(u)*0+1',...
		'Output Width','1',...
		'Mask Display','ON_OFF',...
		'position',[1050,225,1110,265])

add_block('built-in/Mux',[sys,'/','Sorties et stop/Mux'])
set_param([sys,'/','Sorties et stop/Mux'],...
		'BackGround',7,...
		'inputs','[3 3]',...
		'position',[975,198,1025,287])

add_block('built-in/Note',[sys,'/','Sorties et stop/Pour alimenter le ON_OFF'])
set_param([sys,'/','Sorties et stop/Pour alimenter le ON_OFF'],...
		'position',[1110,350,1115,355])

add_block('built-in/Outport',[sys,'/','Sorties et stop/Outport3'])
set_param([sys,'/','Sorties et stop/Outport3'],...
		'BackGround',7,...
		'Port','4',...
		'position',[1215,235,1235,255])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace21'])
set_param([sys,'/','Sorties et stop/To Workspace21'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','marche',...
		'buffer','2',...
		'position',[1140,174,1220,196])

add_block('built-in/To Workspace',[sys,'/','Sorties et stop/To Workspace6'])
set_param([sys,'/','Sorties et stop/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','ON_OFF',...
		'buffer','points_trace',...
		'position',[1145,279,1225,301])
add_line([sys,'/','Sorties et stop'],[325,445;540,445])
add_line([sys,'/','Sorties et stop'],[630,445;645,445])
add_line([sys,'/','Sorties et stop'],[190,490;265,490])
add_line([sys,'/','Sorties et stop'],[325,530;495,530])
add_line([sys,'/','Sorties et stop'],[730,600;760,600])
add_line([sys,'/','Sorties et stop'],[460,445;460,400;515,400])
add_line([sys,'/','Sorties et stop'],[565,400;600,400])
add_line([sys,'/','Sorties et stop'],[460,400;460,350;595,350])
add_line([sys,'/','Sorties et stop'],[565,530;575,530])
add_line([sys,'/','Sorties et stop'],[610,530;655,530])
add_line([sys,'/','Sorties et stop'],[710,495;760,495])
add_line([sys,'/','Sorties et stop'],[710,530;760,530])
add_line([sys,'/','Sorties et stop'],[710,565;760,565])
add_line([sys,'/','Sorties et stop'],[350,445;350,275;405,275])
add_line([sys,'/','Sorties et stop'],[460,240;515,240])
add_line([sys,'/','Sorties et stop'],[550,240;585,240])
add_line([sys,'/','Sorties et stop'],[460,275;515,275])
add_line([sys,'/','Sorties et stop'],[550,275;585,275])
add_line([sys,'/','Sorties et stop'],[550,310;590,310])
add_line([sys,'/','Sorties et stop'],[460,310;515,310])
add_line([sys,'/','Sorties et stop'],[630,530;631,635;910,635])
add_line([sys,'/','Sorties et stop'],[405,750;495,750])
add_line([sys,'/','Sorties et stop'],[725,740;835,740])
add_line([sys,'/','Sorties et stop'],[416,530;415,725;495,725])
add_line([sys,'/','Sorties et stop'],[220,490;220,140;575,140])
add_line([sys,'/','Sorties et stop'],[690,140;720,140])
add_line([sys,'/','Sorties et stop'],[755,140;815,140])
add_line([sys,'/','Sorties et stop'],[785,140;785,115;930,115])
add_line([sys,'/','Sorties et stop'],[775,740;775,815;885,815])
add_line([sys,'/','Sorties et stop'],[220,490;220,705;285,705])
add_line([sys,'/','Sorties et stop'],[220,625;255,625])
add_line([sys,'/','Sorties et stop'],[785,140;785,220;970,220])
add_line([sys,'/','Sorties et stop'],[720,865;1025,865])
add_line([sys,'/','Sorties et stop'],[580,865;685,865])
add_line([sys,'/','Sorties et stop'],[225,705;220,705;220,865;490,865])
add_line([sys,'/','Sorties et stop'],[960,865;970,265])
add_line([sys,'/','Sorties et stop'],[1030,245;1045,245])
add_line([sys,'/','Sorties et stop'],[1115,245;1210,245])
add_line([sys,'/','Sorties et stop'],[1115,245;1115,290;1140,290])
add_line([sys,'/','Sorties et stop'],[1115,245;1115,185;1135,185])
set_param([sys,'/','Sorties et stop'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Sorties et stop'.

set_param([sys,'/','Sorties et stop'],...
		'position',[895,197,1060,273])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'hide name',0,...
		'Vgain','0.100000',...
		'Hgain','20000.000000',...
		'Vmax','0.200000',...
		'Hmax','40000.000000',...
		'Window',[0,0,767,471],...
		'position',[1110,255,1140,285])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[120,123,155,157])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[4,44,1267,968])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,50,1271,885])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1225,300,1245,320])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace1']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','couple_perturb',...
		'buffer','points_trace',...
		'position',[1075,389,1170,421])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain4']],...
		'hide name',0,...
		'Gain','K_aero',...
		'position',[1025,282,1060,308])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','points_trace',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel ']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1220,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1195,310;1195,405;1175,405])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1020,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1065,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[255,317,385,373])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/Gain3'],...
		'hide name',0,...
		'Gain','K_perturbation',...
		'position',[470,332,495,358])


%     Subsystem  'F(X,t) pour la rotation/REGULATION 3 AXES'.

new_system([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[575,47,580,52])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[600,10,605,15])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Couple gnral'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Couple gnral'],...
		'position',[1210,400,1215,405])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Outport1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Outport1'],...
		'hide name',0,...
		'position',[1220,369,1240,391])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sum'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sum'],...
		'position',[1130,203,1155,552])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace6'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace6'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Couple_general',...
		'buffer','points_trace',...
		'position',[1040,159,1160,181])


%     Subsystem  'F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'.

new_system([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],'Location',[4,44,1268,968])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace6'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace6'],...
		'hide name',0,...
		'mat-name','Couple_roue',...
		'buffer','points_trace',...
		'position',[595,549,675,571])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s)']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s)']],...
		'MATLAB Fcn','omeg_sat(u)',...
		'Output Width','3',...
		'Mask Display','omeg_sat.m',...
		'position',[140,354,230,396])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wx'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wx'],...
		'position',[325,310,330,315])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wz'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wz'],...
		'position',[320,390,325,395])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie e(3)'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie e(3)'],...
		'position',[920,480,925,485])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Demux'],...
		'outputs','[1 1 1 4]',...
		'position',[260,136,300,229])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie e(1)'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie e(1)'],...
		'position',[915,450,920,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie de e(2)'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie de e(2)'],...
		'position',[925,350,930,355])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux5'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[1035,337,1080,533])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie vitesse',13,'roue (rd//s)']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie vitesse',13,'roue (rd//s)']],...
		'position',[625,425,630,430])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','omega_roue',...
		'buffer','points_trace',...
		'position',[580,405,660,425])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant1'],...
		'Value','0',...
		'position',[685,611,730,639])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux'],...
		'inputs','3',...
		'position',[770,606,810,714])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant2'],...
		'Value','0',...
		'position',[685,681,730,709])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain3'],...
		'Gain','-1',...
		'position',[855,648,910,672])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple action',13,'roue//satellite',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple action',13,'roue//satellite',13,'vectoriel']],...
		'position',[885,690,890,695])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain2'],...
		'hide name',0,...
		'Gain','K_tangage',...
		'position',[850,359,895,391])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple action',13,'satellite//roue']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple action',13,'satellite//roue']],...
		'position',[575,210,580,215])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain'],...
		'Gain','1/Jroue',...
		'position',[570,322,595,348])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain6'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain6'],...
		'Gain','-1',...
		'position',[570,133,625,157])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant3'],...
		'Value','0',...
		'position',[815,171,860,199])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Mux1'],...
		'inputs','3',...
		'position',[905,125,945,245])


%     Subsystem  ['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product'].

new_system([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],[150,65;180,65])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],[40,100;60,70])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product'].

set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product']],...
		'position',[825,102,850,133])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/r'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/r'],...
		'position',[770,90,775,95])


%     Subsystem  ['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1'].

new_system([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1'].

set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Inner',13,'Product1']],...
		'position',[825,222,850,253])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/h'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/h'],...
		'position',[765,305,770,310])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Moment',13,'Inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Moment',13,'Inertie']],...
		'Gain','Jroue',...
		'position',[715,322,740,348])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Constant'],...
		'Value','h_ref',...
		'position',[695,401,740,429])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum'],...
		'inputs','+-',...
		'position',[780,297,820,453])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Vitesse',13,'roue']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Vitesse',13,'roue']],...
		'position',[640,280,645,285])

add_block('built-in/Integrator',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Integrator'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Integrator'],...
		'Initial',' omega_roue_ref',...
		'position',[615,319,670,351])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/p'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/p'],...
		'position',[390,125,395,130])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/r '])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/r '],...
		'position',[390,175,395,180])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/q'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/q'],...
		'position',[310,155,315,160])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/rotation relative',13,'en repre',13,'satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/rotation relative',13,'en repre',13,'satellite']],...
		'position',[280,450,285,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/pqrQ'],...
		'position',[205,140,210,145])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Demux1'],...
		'outputs','3',...
		'position',[260,316,300,434])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Q'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Q'],...
		'position',[310,210,315,215])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie B',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[280,825,285,830])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wy'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/wy'],...
		'position',[320,355,325,360])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain5'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain5'],...
		'Gain','KD_roue',...
		'position',[370,362,395,388])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain4'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain4'],...
		'Gain','KP_roue',...
		'position',[370,282,395,308])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum1'],...
		'position',[410,257,450,413])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product'],...
		'BackGround',7,...
		'position',[470,206,495,379])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/in_2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/in_2'],...
		'BackGround',7,...
		'position',[45,240,65,260])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/in_1'],...
		'Port','2',...
		'position',[35,365,55,385])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/pqrQ '])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/pqrQ '],...
		'position',[45,400,50,405])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Entre de ',13,'ON_OFF']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Entre de ',13,'ON_OFF']],...
		'position',[60,270,65,275])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/To Workspace2'],...
		'hide name',0,...
		'mat-name','couple_gyroscopique',...
		'buffer','points_trace',...
		'position',[1060,69,1185,91])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product1'],...
		'BackGround',7,...
		'position',[985,44,1015,231])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out 2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out 2'],...
		'position',[1075,127,1100,153])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']],...
		'position',[1115,175,1120,180])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Product3'],...
		'BackGround',7,...
		'position',[1135,391,1160,564])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out_3_'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out_3_'],...
		'Port','3',...
		'position',[1215,470,1235,490])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie de ',13,'du vecteur e']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sortie de ',13,'du vecteur e']],...
		'position',[1205,390,1210,395])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/out_1'],...
		'Port','2',...
		'position',[975,650,995,670])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple roue//satellite',13,'scalaire sur',13,'tangage',13,'(Satellite//roue)']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Couple roue//satellite',13,'scalaire sur',13,'tangage',13,'(Satellite//roue)']],...
		'position',[950,560,955,565])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_OFF qui coupe le couple gyroscopique'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_OFF qui coupe le couple gyroscopique'],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[490,65,495,70])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_OFF qui coupe le couple gyroscopique1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_OFF qui coupe le couple gyroscopique1'],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[510,85,515,90])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON OFF qui annule le moment magntique e'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON OFF qui annule le moment magntique e'],...
		'ForeGround',7,...
		'position',[500,750,505,755])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_Off qui annule le couple roue',13,'stabilise la rotation',13,'annule le couple sur satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/ON_Off qui annule le couple roue',13,'stabilise la rotation',13,'annule le couple sur satellite']],...
		'ForeGround',7,...
		'position',[185,35,190,40])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation relative',13,'( rd//s)1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation relative',13,'( rd//s)1']],...
		'MATLAB Fcn','-u(5)',...
		'Output Width','1',...
		'Mask Display','Quaternion erreur(2)',...
		'position',[140,274,270,316])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum2'],...
		'position',[415,450,455,550])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain1'],...
		'hide name',0,...
		'Gain','K_lacet',...
		'position',[370,462,395,488])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain8'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain8'],...
		'hide name',0,...
		'Gain','Kp_lacet',...
		'position',[360,512,385,538])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Sum3'],...
		'position',[425,582,465,738])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain7'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain7'],...
		'hide name',0,...
		'Gain','K_roulis',...
		'position',[375,607,400,633])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain9'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Gain9'],...
		'hide name',0,...
		'Gain','Kp_roulis',...
		'position',[375,687,400,713])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s)  ']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s)  ']],...
		'MATLAB Fcn','u(4)',...
		'Output Width','1',...
		'Mask Display','Quaternion(1)',...
		'position',[155,679,285,721])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s) ']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE/Rotation',13,'relative',13,'( rd//s) ']],...
		'MATLAB Fcn','u(6)',...
		'Output Width','1',...
		'Mask Display','Quaternion (3)',...
		'position',[145,504,275,546])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[305,415;350,415;350,475;365,475])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[60,375;115,375;115,185;255,185])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[305,375;365,375])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[115,375;135,375])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[305,195;515,195;515,110;820,110])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[305,145;565,145])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[630,145;710,145;710,230;820,230])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[400,295;405,295])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[400,375;405,375])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[235,375;255,375])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[815,660;850,660])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[855,120;880,120;880,145;900,145])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[855,240;885,240;885,225;900,225])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[865,185;900,185])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[745,335;745,125;820,125])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[745,245;820,245])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[675,335;665,415])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[735,695;765,695])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[735,625;765,625])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[900,375;960,375;960,435;1030,435])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[600,335;610,335])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[675,335;710,335])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[745,335;775,335])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[745,415;775,415])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[825,375;845,375])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[70,250;465,250])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[455,335;465,335])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[500,295;515,295;515,660;765,660])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[515,560;590,560])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[515,335;565,335])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[90,250;90,90;980,90])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[950,185;980,185])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[1020,140;1070,140])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[1040,140;1040,80;1055,80])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[1085,435;1130,435])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[1165,480;1210,480])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[915,660;970,660])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[90,250;90,750;1100,750;1100,520;1130,520])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[275,295;365,295])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[400,475;410,475])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[280,525;355,525])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[390,525;410,525])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[460,500;1030,500])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[290,700;370,700])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[115,375;120,375;120,700;150,700])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[405,700;420,700])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[405,620;420,620])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[305,335;340,335;340,620;370,620])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[470,660;495,660;495,475;1005,475;1005,370;1030,370])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[115,295;135,295])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],[120,525;140,525])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],...
		'Mask Display','FONCTIONNEMENT\nDE LA ROUE\nET SORTIE DE e(2)')


%     Finished composite block 'F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'.

set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/FONCTION ROUE'],...
		'position',[85,271,280,379])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Couple magntique',13,'1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','u/norm(u)',...
		'Output Width','3',...
		'position',[355,511,445,549])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/B'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/B'],...
		'position',[345,505,350,510])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace4'],...
		'hide name',0,...
		'mat-name','e',...
		'buffer','points_trace',...
		'position',[460,349,495,371])


%     Subsystem  ['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],'Location',[59,535,1014,1004])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[880,85,885,90])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Axes satellite']],...
		'position',[875,110,880,115])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[885,150,905,170])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],[625,160;880,160])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Champ magntique',13,'en axes satellite_']],...
		'position',[125,492,325,568])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'hide name',0,...
		'position',[60,610,65,615])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Sortie B',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[210,440,215,445])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/vecteur ',13,'B//||B||']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/vecteur ',13,'B//||B||']],...
		'position',[470,490,475,495])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/vecteur e'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/vecteur e'],...
		'position',[465,430,470,435])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux4'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[495,379,535,581])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Moment ',13,'magntique',13,'brut']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Moment ',13,'magntique',13,'brut']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[550,461,640,499])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Moment',13,'magntique']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Moment',13,'magntique']],...
		'position',[590,415,595,420])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux7'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux7'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[670,469,705,516])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Saturation'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Saturation'],...
		'MATLAB Fcn','magn_sat(u)',...
		'Output Width','3',...
		'position',[720,476,810,514])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace2'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','moment_magnetique',...
		'buffer','points_trace',...
		'position',[665,434,805,456])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux6'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Mux6'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[845,443,875,647])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Couple magntique'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Couple magntique'],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[895,526,985,564])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain2'],...
		'Gain','K_CPL_MGN_NUL',...
		'position',[1000,532,1025,558])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/To Workspace3'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Couple_magnetique',...
		'buffer','points_trace',...
		'position',[890,474,1010,496])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sum1'],...
		'position',[1045,415,1075,510])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain4'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain4'],...
		'hide name',0,...
		'Gain','K_ROUE_CSTE',...
		'position',[465,271,645,309])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Couple  gyroscopique ',13,' action roue sur satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Couple  gyroscopique ',13,' action roue sur satellite']],...
		'position',[785,270,790,275])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Couple action',13,'roue sur satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/Couple action',13,'roue sur satellite']],...
		'position',[890,320,895,325])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Sur le satellite,il agit l''oppos du couple roue']])
set_param([sys,'/',['F(X,t) pour la rotation/REGULATION 3 AXES/NB : Sur le satellite,il agit l''oppos du couple roue']],...
		'position',[790,355,795,360])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 1'],...
		'position',[335,265,340,270])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 2 :'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 2 :'],...
		'position',[340,300,345,305])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Sortie 3'],...
		'position',[330,330,335,335])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/e'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/e'],...
		'position',[415,405,420,410])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/pqrQ '])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/pqrQ '],...
		'position',[60,545,65,550])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/in_1'],...
		'hide name',0,...
		'Port','2',...
		'position',[15,520,35,540])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/in_2'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/in_2'],...
		'hide name',0,...
		'position',[35,290,55,310])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES/Gain3'],...
		'hide name',0,...
		'Gain','K_CPL_ROUE_NUL',...
		'position',[635,305,810,345])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[1030,545;1040,485])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[1030,485;1015,485])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[1080,465;1125,465])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[815,325;985,325;985,440;1040,440])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[710,495;715,495])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[330,530;330,595;840,595])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[650,595;650,505;665,505])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[645,480;665,480])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[815,495;840,495])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[825,495;825,445;810,445])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[285,325;630,325])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[1160,380;1215,380])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[1190,380;1190,170;1165,170])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[285,290;460,290])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[650,290;1125,290])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[990,545;995,545])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[880,545;890,545])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[330,530;350,530])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[450,530;490,530])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[285,360;365,360;365,430;490,430])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[445,430;455,360])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[540,480;545,480])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[40,530;120,530])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[54,530;55,355;80,355])
add_line([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],[60,300;80,300])
set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],...
		'Mask Display','REGULATION 3 AXES \nDE\nSTEYN ET ROUE')


%     Finished composite block 'F(X,t) pour la rotation/REGULATION 3 AXES'.

set_param([sys,'/','F(X,t) pour la rotation/REGULATION 3 AXES'],...
		'position',[215,209,435,291])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[330,414,455,466])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[210,410,260,530])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[285,405,290,410])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'hide name',0,...
		'Port','2',...
		'position',[70,335,90,355])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'hide name',0,...
		'position',[100,370,105,375])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/tau',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/tau',13,'']],...
		'hide name',0,...
		'position',[80,275,85,280])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[285,495,290,500])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/sortie de Q'])
set_param([sys,'/','F(X,t) pour la rotation/sortie de Q'],...
		'position',[345,500,350,505])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'hide name',0,...
		'Gain','K_commande',...
		'position',[605,238,645,262])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/Sum2'],...
		'position',[670,202,700,393])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'position',[885,229,925,511])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','Inv_Asat',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[750,277,850,323])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'hide name',0,...
		'position',[1055,360,1075,380])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'hide name',0,...
		'position',[980,357,1005,383])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport1'])
set_param([sys,'/','F(X,t) pour la rotation/Inport1'],...
		'hide name',0,...
		'position',[75,165,95,185])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Product'],...
		'position',[465,135,490,290])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/NB : la rgulation 3 axes est mise en oeuvre ds que l''angle de tangage est infrieur  20']])
set_param([sys,'/',['F(X,t) pour la rotation/NB : la rgulation 3 axes est mise en oeuvre ds que l''angle de tangage est infrieur  20']],...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[605,30,610,35])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/La fonction ON_OFF active la rgulation si les anles de dpointages sont  au dessus du seuil haut'])
set_param([sys,'/','F(X,t) pour la rotation/La fonction ON_OFF active la rgulation si les anles de dpointages sont  au dessus du seuil haut'],...
		'Font Size',14,...
		'position',[540,620,545,625])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/dsactive cette fonction quand les angles sont sous le seuil fix'])
set_param([sys,'/','F(X,t) pour la rotation/dsactive cette fonction quand les angles sont sous le seuil fix'],...
		'Font Size',14,...
		'position',[565,650,570,655])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/commande l''arrt du couple roue ( pour la simulation )']])
set_param([sys,'/',['F(X,t) pour la rotation/commande l''arrt du couple roue ( pour la simulation )']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,675,535,680])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Entre du ON_OFF qui autorise ou non la rgulation'])
set_param([sys,'/','F(X,t) pour la rotation/Entre du ON_OFF qui autorise ou non la rgulation'],...
		'position',[215,140,220,145])
add_line([sys,'/','F(X,t) pour la rotation'],[100,175;460,175])
add_line([sys,'/','F(X,t) pour la rotation'],[460,440;880,440])
add_line([sys,'/','F(X,t) pour la rotation'],[705,300;745,300])
add_line([sys,'/','F(X,t) pour la rotation'],[500,345;665,345])
add_line([sys,'/','F(X,t) pour la rotation'],[650,250;665,250])
add_line([sys,'/','F(X,t) pour la rotation'],[390,345;465,345])
add_line([sys,'/','F(X,t) pour la rotation'],[855,300;880,300])
add_line([sys,'/','F(X,t) pour la rotation'],[95,345;250,345])
add_line([sys,'/','F(X,t) pour la rotation'],[185,345;185,470;205,470])
add_line([sys,'/','F(X,t) pour la rotation'],[1010,370;1050,370])
add_line([sys,'/','F(X,t) pour la rotation'],[930,370;975,370])
add_line([sys,'/','F(X,t) pour la rotation'],[265,440;325,440])
add_line([sys,'/','F(X,t) pour la rotation'],[440,250;460,250])
add_line([sys,'/','F(X,t) pour la rotation'],[495,215;550,215;550,250;600,250])
add_line([sys,'/','F(X,t) pour la rotation'],[185,345;185,270;210,270])
add_line([sys,'/','F(X,t) pour la rotation'],[160,175;160,230;210,230])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[235,233,460,317])

add_block('built-in/Note',[sys,'/',['Utilisation d''une roue sur le tangage et de 3 magntocoupleurs',13,'dsaturation en continu, vitesse roue maintenue quasi constante']])
set_param([sys,'/',['Utilisation d''une roue sur le tangage et de 3 magntocoupleurs',13,'dsaturation en continu, vitesse roue maintenue quasi constante']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Utilisation d''une roue sur le tangage et de 3 magntocoupleurs',13,'dsaturation en continu, vitesse roue maintenue quasi constante']],...
		'Font Size',18,...
		'position',[625,85,630,90])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[625,845,830,911])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Vrification\n\nq constante',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[440,845,615,911])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Vrification\n\nenergie constante',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[255,840,430,906])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Vrification\np2plusr2 constante\nrotation transverse',...
		'Mask Dialogue','eval(''plot(temps,p2plusr2);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[70,840,245,911])


%     Subsystem  'Extras28'.

new_system([sys,'/','Extras28'])
set_param([sys,'/','Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras28'],...
		'Mask Display','COMMUTATEUR\n\nON_OFF',...
		'Mask Dialogue','eval(''plot(temps,ON_OFF);grid;figure(gcf)'')')


%     Finished composite block 'Extras28'.

set_param([sys,'/','Extras28'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[840,840,1015,906])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''clear;clc;stn3dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[910,350,1125,421])

add_block('built-in/Note',[sys,'/',['Angles ',13,'de Cardan()']])
set_param([sys,'/',['Angles ',13,'de Cardan()']],...
		'position',[1185,150,1190,155])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','20000.000000',...
		'Vmax','20.000000',...
		'Hmax','40000.000000',...
		'Window',[0,0,849,487],...
		'position',[1105,160,1135,190])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Vgain','5.000000',...
		'Hgain','60000.000000',...
		'Vmax','10.000000',...
		'Hmax','120000.000000',...
		'Window',[27,300,967,828])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[1110,210,1140,240])

add_block('built-in/Note',[sys,'/',['Dpointages',13,'en degrs']])
set_param([sys,'/',['Dpointages',13,'en degrs']],...
		'position',[1190,205,1195,210])

add_block('built-in/Note',[sys,'/',['Vitesses angulaires',13,'par rapport au',13,'repre orbital',13,'en //s']])
set_param([sys,'/',['Vitesses angulaires',13,'par rapport au',13,'repre orbital',13,'en //s']],...
		'position',[1205,250,1210,255])

add_block('built-in/Note',[sys,'/','CAS PARTICULIERS A CHOISIR AVEC LES COEFFICIENTS CORRECTS DANS stn0dat.m'])
set_param([sys,'/','CAS PARTICULIERS A CHOISIR AVEC LES COEFFICIENTS CORRECTS DANS stn0dat.m'],...
		'Font Name','Arial Black',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[460,815,465,820])
add_line(sys,[840,350;860,350;860,505;150,505;150,420;230,420])
add_line(sys,[675,350;730,350])
add_line(sys,[465,275;605,275])
add_line(sys,[455,420;605,420])
add_line(sys,[860,350;860,215;890,215])
add_line(sys,[150,420;150,295;230,295])
add_line(sys,[1065,205;1100,175])
add_line(sys,[710,350;710,255;890,255])
add_line(sys,[1065,225;1105,225])
add_line(sys,[1065,245;1070,245;1105,270])
add_line(sys,[1065,265;1075,265;1075,300;875,300;875,530;130,530;130,255;230,255])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
