function [ret,x0,str,ts,xts]=tumble00(t,x,u,flag);
%TUMBLE00	is the M-file description of the SIMULINK system named TUMBLE00.
%	The block-diagram can be displayed by typing: TUMBLE00.
%
%	SYS=TUMBLE00(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TUMBLE00 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TUMBLE00 with a FLAG of zero:
%	[SIZES]=TUMBLE00([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[2,44,1266,952])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '25000')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[650,505,655,510])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[240,510,245,515])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[425,485,430,490])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[480,240,485,245])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[470,420,475,425])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[0,40,1264,964])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,368,395,472])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[555,204,615,491])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[680,324,780,376])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[575,255,580,260])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[570,395,575,400])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[745,470,750,475])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/SIMULATION COMPRENANT :'])
set_param([sys,'/','F(X,t) pour la rotation/SIMULATION COMPRENANT :'],...
		'Font Angle','italic',...
		'Font Size',18,...
		'position',[550,10,555,15])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/De 0  Temps_phase1 la rgulation en beta prime avec un magntocoupleur sur l''axe y']])
set_param([sys,'/',['F(X,t) pour la rotation/De 0  Temps_phase1 la rgulation en beta prime avec un magntocoupleur sur l''axe y']],...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[630,55,635,60])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/De Temps_phase2  Temps_phase3 la mise en spin par magntocoupleurs sur les axes x et z'])
set_param([sys,'/','F(X,t) pour la rotation/De Temps_phase2  Temps_phase3 la mise en spin par magntocoupleurs sur les axes x et z'],...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[655,90,660,95])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[535,504,660,556])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[415,500,465,620])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[485,590,490,595])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[490,495,495,500])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'position',[275,425,295,445])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[305,460,310,465])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/tau',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/tau',13,'']],...
		'position',[285,365,290,370])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,50,1271,885])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[440,407,570,463])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'position',[1000,425,1020,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'position',[930,422,955,448])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','Inv_Asat',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[735,317,835,363])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Gain'],...
		'Gain','K_perturbation',...
		'position',[780,422,805,448])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'Gain','K_commande',...
		'position',[675,328,715,352])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'inputs','+++',...
		'position',[860,294,900,576])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[620,10,625,15])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'position',[595,47,600,52])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Les moments magntiques sont limits  0.2 A-m'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Les moments magntiques sont limits  0.2 A-m'],...
		'position',[565,105,570,110])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'hide name',0,...
		'position',[15,450,20,455])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple',13,' magntique']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple',13,' magntique']],...
		'position',[615,295,620,300])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple magntique',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple magntique',13,'']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[580,336,670,374])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','norme_cpl_steyn',...
		'buffer','points_trace',...
		'position',[370,444,490,466])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple magntique',13,'2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple magntique',13,'2']],...
		'orientation',2,...
		'hide name',0,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'position',[525,436,615,474])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/in_1'],...
		'hide name',0,...
		'position',[230,345,245,365])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],'Location',[4,44,1268,968])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace14'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace14'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Mz',...
		'buffer','points_trace',...
		'position',[775,129,810,151])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace13'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace13'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','My',...
		'buffer','points_trace',...
		'position',[775,104,810,126])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace12'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/To Workspace12'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Mx',...
		'buffer','points_trace',...
		'position',[775,79,810,101])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Demux5'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Demux5'],...
		'orientation',2,...
		'outputs','3',...
		'position',[825,78,870,152])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sum6'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sum6'],...
		'hide name',0,...
		'position',[675,154,695,201])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '],...
		'Font Name','Arial Narrow',...
		'Font Size',18)
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '],...
		'position',[625,35,630,40])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Vecteur champ'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Vecteur champ'],...
		'position',[435,475,440,480])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /B'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /B'],...
		'hide name',0,...
		'position',[485,440,490,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Gain1'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[410,416,465,454])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /beta et beta_prime'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /beta et beta_prime'],...
		'hide name',0,...
		'position',[425,310,430,315])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /B  '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /B  '],...
		'position',[180,315,185,320])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /in_1'],...
		'position',[160,350,180,370])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','beta_tg(u)',...
		'Output Width','1',...
		'Mask Display','beta_tg',...
		'position',[260,343,320,377])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Moment My qui doit :',13,'Fonctionner en continu depuis le temps 0',13,'',13,'  ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Moment My qui doit :',13,'Fonctionner en continu depuis le temps 0',13,'',13,'  ']],...
		'Font Name','Arial Narrow',...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Moment My qui doit :',13,'Fonctionner en continu depuis le temps 0',13,'',13,'  ']],...
		'position',[600,85,605,90])

add_block('built-in/Derivative',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Derivative'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Derivative'],...
		'hide name',0,...
		'position',[360,343,410,377])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /beta',13,'prime']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /beta',13,'prime']],...
		'position',[385,295,390,300])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Gain'],...
		'hide name',0,...
		'Gain','K_beta',...
		'position',[450,346,495,374])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Sortie du moment',13,'magntique My',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Sortie du moment',13,'magntique My',13,'']],...
		'position',[875,285,880,290])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /out_1'],...
		'position',[880,350,900,370])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /To Workspace2'],...
		'hide name',0,...
		'mat-name','M_beta',...
		'buffer','points_trace',...
		'position',[830,410,910,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /My',13,'vecteur1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /My',13,'vecteur1']],...
		'position',[730,395,735,400])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Mux5'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[715,320,745,400])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Constant3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[680,375,700,395])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Constant2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[680,325,700,345])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Moment magntique',13,'brut avant optimisation']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Moment magntique',13,'brut avant optimisation']],...
		'position',[720,260,725,265])

add_block('built-in/Saturation',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Saturation'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Saturation'],...
		'position',[560,348,590,372])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Saturation  + 0.5 pou',13,'viter les sauts de ',13,'drives importants']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Saturation  + 0.5 pou',13,'viter les sauts de ',13,'drives importants']],...
		'position',[570,270,575,275])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /To Workspace3'],...
		'hide name',0,...
		'mat-name','beta_steyn',...
		'buffer','points_trace',...
		'position',[530,425,610,445])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Vecteur 3 composantes'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My /Vecteur 3 composantes'],...
		'position',[730,430,735,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[325,360;325,435;405,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[470,435;525,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[325,360;355,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[415,360;445,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[750,360;875,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[800,360;800,420;825,420])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[185,360;255,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[705,335;710,335])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[705,385;710,385])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[500,360;555,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],[595,360;710,360])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],...
		'Mask Display','Calcul de My\ncommande de Steyn\navec l''angle beta driv')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Calcul de My '],...
		'position',[425,217,580,293])


%     Subsystem  ['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2'].

new_system([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],'Location',[59,535,1014,1004])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Axes satellite']],...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Sortie Bx By Bz']],...
		'position',[715,95,720,100])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/out_1']],...
		'position',[720,150,740,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/in_1']],...
		'position',[140,190,160,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[140,235,145,240])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],[165,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],[625,160;715,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],[220,120;245,120])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2'].

set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Champ magntique',13,'en axes satellite_2']],...
		'position',[105,218,290,292])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],'Location',[0,40,1264,964])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Moment Mx qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Moment Mx qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'Font Name','Arial Narrow')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Moment Mx qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Moment Mx qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'position',[575,20,580,25])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /out_1'],...
		'position',[805,265,825,285])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Product'],...
		'position',[750,209,775,336])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Arrt de la premire phase'],...
		'position',[540,185,545,190])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Clock'],...
		'position',[330,222,365,258])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Calcul de  Mx'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Calcul de  Mx'],...
		'MATLAB Fcn','Mx_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mx\nsans saturation',...
		'position',[550,281,705,329])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Mux'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /Mux'],...
		'inputs','[10 1]',...
		'position',[480,269,510,336])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /in_1'],...
		'position',[435,275,455,295])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx /MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','((u-temps_phase2)>0)*((u-temps_phase3)<0)',...
		'Output Width','1',...
		'position',[555,223,615,257])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[710,305;745,305])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[370,240;550,240])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[620,240;745,240])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[780,275;800,275])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[515,305;545,305])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[460,285;475,285])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],[380,240;380,320;475,320])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],...
		'Mask Display','Calcul de M avec\ndclenchement dcal\nsans saturation\navant regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mx '],...
		'position',[430,134,580,196])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Couple magntique',13,'4']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Couple magntique',13,'4']],...
		'hide name',0,...
		'MATLAB Fcn','magn_sat(u)',...
		'Output Width','3',...
		'position',[810,236,900,274])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux12'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux12'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[355,294,390,381])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux11'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux11'],...
		'hide name',0,...
		'inputs','3',...
		'position',[715,191,735,319])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux10'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux10'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[925,188,960,452])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Demux4'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[595,239,645,271])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sum5'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sum5'],...
		'hide name',0,...
		'position',[670,304,690,351])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux9'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mux9'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[770,223,790,352])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sortie B',13,'axes satellite2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Sortie B',13,'axes satellite2']],...
		'hide name',0,...
		'position',[185,173,190,178])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],'Location',[4,44,1268,968])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /in_1'],...
		'position',[385,385,405,405])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Mux'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Mux'],...
		'inputs','[10 1]',...
		'position',[435,380,465,435])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Clock'],...
		'position',[290,327,325,363])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Calcul de Mz'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Calcul de Mz'],...
		'MATLAB Fcn','Mz_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mz\navec saturation',...
		'position',[495,386,650,434])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','((u-temps_phase2)>0)*((u-temps_phase3)<0)',...
		'Output Width','1',...
		'position',[515,328,575,362])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Product'],...
		'position',[705,314,730,441])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /out_1'],...
		'position',[760,370,780,390])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Moment Mz qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Moment Mz qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'Font Name','Arial Narrow')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Moment Mz qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Moment Mz qui doit :',13,'tre nul avant temps_phase2',13,'disparatre pendant la phase de fonctionnement de la roue donc aprs temps_phase3',13,'et',13,'agir entre temps_phase2 et temps_phase3',13,'  ']],...
		'position',[550,70,555,75])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz /Arrt de la premire phase'],...
		'position',[540,290,545,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[655,410;700,410])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[330,345;510,345])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[580,345;700,345])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[735,380;755,380])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[470,410;490,410])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[410,395;430,395])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],[330,345;330,420;430,420])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],...
		'Mask Display','Calcul de Mz avec\ndclenchement dcal\nsans saturation\navant regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/Mz '],...
		'position',[425,312,585,368])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/out_1'],...
		'position',[990,310,1010,330])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/pqrQ '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/pqrQ '],...
		'position',[205,333,210,338])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55/in_1'],...
		'position',[40,245,60,265])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[295,255;340,255;340,385;920,385])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[740,385;740,320;765,320])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[740,255;765,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[795,290;805,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[820,140;815,140])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[820,115;815,115])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[820,90;815,90])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[905,255;905,115;875,115])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[905,255;920,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[295,255;340,255;350,315])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[695,330;695,295;710,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[650,255;710,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[700,180;710,215])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[650,265;655,265;665,315])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[650,245;660,245;670,190])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[585,165;670,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[585,255;590,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[295,255;420,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[395,340;420,340])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[590,340;665,340])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[395,340;395,165;425,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[65,255;100,255])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[965,320;985,320])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],[65,255;65,360;350,360])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],...
		'Mask Display','MOMENT MAGNETIQUE\n\nDES MAGNETOCOUPLEURS')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/magntos 55'],...
		'position',[330,301,540,409])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/To Workspace'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_steyn',...
		'buffer','points_trace',...
		'position',[745,275,825,295])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/out_1'],...
		'position',[1010,440,1030,460])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple de',13,'Steyn gnral']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Couple de',13,'Steyn gnral']],...
		'position',[785,295,790,300])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Sum1'],...
		'position',[865,264,925,631])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/Gain'],...
		'position',[680,527,705,553])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Suppresion possible de la roue',13,'ave K=0 sibnon K=1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/Suppresion possible de la roue',13,'ave K=0 sibnon K=1']],...
		'position',[670,585,675,590])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],'Location',[147,384,987,794])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/pqrQ'],...
		'position',[70,130,75,135])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Vitesse',13,'roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Vitesse',13,'roue']],...
		'position',[75,195,80,200])


%     Subsystem  ['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1'].

new_system([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],[40,100;60,70])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],[150,65;180,65])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1'].

set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product1']],...
		'hide name',0,...
		'position',[470,192,495,223])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/r'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/r'],...
		'position',[415,60,420,65])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Demux'],...
		'outputs','[1 1 1 4]',...
		'position',[160,100,205,190])


%     Subsystem  ['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product'].

new_system([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product'].

set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Inner',13,'Product']],...
		'hide name',0,...
		'position',[470,72,495,103])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Mux1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Mux1'],...
		'inputs','3',...
		'position',[550,95,590,215])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Constant3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[460,141,505,169])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain1'],...
		'Gain','-1',...
		'position',[245,103,300,127])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/p'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/p'],...
		'position',[220,90,225,95])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/in_1'],...
		'position',[110,135,130,155])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/r '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/r '],...
		'position',[305,135,310,140])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/q'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/q'],...
		'position',[220,130,225,135])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Q'],...
		'position',[220,170,225,175])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/in_2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/in_2'],...
		'Port','2',...
		'position',[110,205,130,225])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/To Workspace9'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/To Workspace9'],...
		'hide name',0,...
		'mat-name','vitesse_roue',...
		'buffer','points_trace',...
		'position',[465,262,560,288])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain'],...
		'Gain','30/pi',...
		'position',[265,260,305,290])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Vitesse en tours//mn '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Vitesse en tours//mn '],...
		'position',[365,250,370,255])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/out_3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/out_3'],...
		'position',[720,145,740,165])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Gain2'],...
		'Gain','Jroue',...
		'position',[630,140,670,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique/Couple gyroscopique',13,'roue//satellite',13,'avec le bon signe']],...
		'position',[750,65,755,70])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[210,155;360,155;360,80;465,80])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[210,115;240,115])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[305,115;340,115;340,200;465,200])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[510,155;545,155])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[500,210;530,210;530,195;545,195])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[500,90;525,90;525,115;545,115])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[135,215;465,215])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[135,145;155,145])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[400,215;400,95;465,95])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[310,275;460,275])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[235,215;235,275;260,275])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[595,155;625,155])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],[675,155;715,155])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],...
		'Mask Display','COUPLE\nGYROSCOPIQUE\n(Roue/satellite)')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple gyroscopique'],...
		'position',[400,209,580,276])


%     Subsystem  'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Calcul du couple d''annulation du spin satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Calcul du couple d''annulation du spin satellite']],...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Programmation de la',13,'rduction du moment cintique']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Programmation de la',13,'rduction du moment cintique']],...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[445,25,450,30])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Vitesse de la roue (rd//s)'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Vitesse de la roue (rd//s)'],...
		'position',[815,345,820,350])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Couple reu par la roue'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Couple reu par la roue'],...
		'position',[590,315,595,320])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain1'],...
		'hide name',0,...
		'Gain','coeff_A',...
		'position',[270,245,355,275])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /To Workspace4'],...
		'hide name',0,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[570,340,650,360])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Clock'],...
		'position',[80,182,115,218])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain'],...
		'Gain','-1',...
		'position',[685,215,725,245])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /zero'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /zero'],...
		'hide name',0,...
		'Value','0',...
		'position',[525,181,560,209])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Mux2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[605,177,640,283])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /zero1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /zero1'],...
		'hide name',0,...
		'Value','0',...
		'position',[530,251,565,279])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Product'],...
		'position',[470,169,495,291])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Sum2'],...
		'inputs','+-',...
		'position',[215,219,235,301])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Dbut phase3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Dbut phase3'],...
		'Value','temps_phase3',...
		'position',[65,268,180,292])

add_block('built-in/Integrator',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Integrator'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Integrator'],...
		'position',[685,369,720,411])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Gain2'],...
		'hide name',0,...
		'Gain','1/Jroue',...
		'position',[590,375,630,405])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /out_2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /out_2'],...
		'Port','2',...
		'position',[855,378,880,402])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /attention!!!!'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /attention!!!!'],...
		'position',[600,425,605,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Valeur 1 uniquement entre T3 et t3+Dt',13,'sinon 0']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Valeur 1 uniquement entre T3 et t3+Dt',13,'sinon 0']],...
		'position',[305,140,310,145])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','((u-temps_phase3)>0)*((u-(temps_phase3+temps_stop))<0)',...
		'Output Width','1')
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /MATLAB Fcn2'],...
		'position',[270,183,330,217])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Inversion du couple roue',13,'pour obtenir le couple //satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Inversion du couple roue',13,'pour obtenir le couple //satellite']],...
		'position',[770,160,775,165])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Couple roue//satellite',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /Couple roue//satellite',13,'vectoriel']],...
		'position',[770,260,775,265])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue /out_1'],...
		'position',[845,220,865,240])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[335,200;465,200])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[120,200;265,200])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[565,195;600,195])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[500,230;600,230])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[570,265;600,265])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[645,230;680,230])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[730,230;840,230])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[120,200;120,240;210,240])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[185,280;210,280])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[240,260;265,260])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[510,230;510,350;565,350])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[360,260;465,260])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[510,350;510,390;585,390])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[635,390;680,390])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],[725,390;850,390])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],...
		'Mask Display','Couple et vitesse roue \nde rduction du moment\ncintique satellite')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple et vitesse roue '],...
		'position',[115,103,290,167])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Vectoriel'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Vectoriel'],...
		'position',[395,157,400,162])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/in_1'],...
		'position',[115,215,135,235])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/pqrQ'],...
		'position',[200,200,205,205])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/To Workspace10'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/To Workspace10'],...
		'hide name',0,...
		'mat-name','cpl_gyro',...
		'buffer','points_trace',...
		'position',[660,232,755,258])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Sum1'],...
		'position',[680,59,715,181])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/out_1'],...
		'position',[750,110,770,130])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple roue//satellite'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE/Couple roue//satellite'],...
		'position',[475,65,480,70])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[585,245;655,245])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[295,150;315,150;315,260;395,260])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[140,225;395,225])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[620,245;620,150;675,150])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[295,120;520,120;520,90;675,90])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],[720,120;745,120])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],...
		'Mask Display','COUPLE ROUE\n\nET COUPLE GYROSCOPIQUE\n\nSUR LE SATELLITE')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn/ROUE COMPLETE'],...
		'position',[345,498,590,582])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[675,355;860,355])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[675,355;675,285;740,285])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[520,455;495,455])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[675,355;675,455;620,455])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[545,355;575,355])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[250,355;325,355])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[264,355;265,540;340,540])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[930,450;1005,450])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[595,540;675,540])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],[710,540;860,540])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],...
		'Mask Display','REGULATION TUMBLING \nMISE EN SPIN \nPUIS DESPIN AVEC\n ROUE  VERS SA VITESSE\nDE CONSIGNE')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation de Steyn'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation de Steyn'],...
		'position',[430,299,650,381])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Aprs cessation du couple roue, le satellite rejoint par effet d''alignement gyroscopique l''',13,'attitude Y_Thomson o y vient se positionner  l''oppos de Y']])
set_param([sys,'/',['F(X,t) pour la rotation/Aprs cessation du couple roue, le satellite rejoint par effet d''alignement gyroscopique l''',13,'attitude Y_Thomson o y vient se positionner  l''oppos de Y']],...
		'Font Angle','italic')
set_param([sys,'/',['F(X,t) pour la rotation/Aprs cessation du couple roue, le satellite rejoint par effet d''alignement gyroscopique l''',13,'attitude Y_Thomson o y vient se positionner  l''oppos de Y']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Aprs cessation du couple roue, le satellite rejoint par effet d''alignement gyroscopique l''',13,'attitude Y_Thomson o y vient se positionner  l''oppos de Y']],...
		'position',[625,180,630,185])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/De temps_phase3  Temps_phase3+Temps_stop la mise en oeuvre de la roue partant de la ',13,'vitesse nulle pour rejoindre sa consigne de -600 tours//mn, en absorbant le spin du nanosatellite']])
set_param([sys,'/',['F(X,t) pour la rotation/De temps_phase3  Temps_phase3+Temps_stop la mise en oeuvre de la roue partant de la ',13,'vitesse nulle pour rejoindre sa consigne de -600 tours//mn, en absorbant le spin du nanosatellite']],...
		'Font Angle','italic')
set_param([sys,'/',['F(X,t) pour la rotation/De temps_phase3  Temps_phase3+Temps_stop la mise en oeuvre de la roue partant de la ',13,'vitesse nulle pour rejoindre sa consigne de -600 tours//mn, en absorbant le spin du nanosatellite']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/De temps_phase3  Temps_phase3+Temps_stop la mise en oeuvre de la roue partant de la ',13,'vitesse nulle pour rejoindre sa consigne de -600 tours//mn, en absorbant le spin du nanosatellite']],...
		'position',[650,125,655,130])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace12'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','points_trace',...
		'position',[520,580,590,600])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite2']])
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite2']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','Inv_Asat',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[620,412,720,458])
add_line([sys,'/','F(X,t) pour la rotation'],[470,530;530,530])
add_line([sys,'/','F(X,t) pour la rotation'],[665,530;855,530])
add_line([sys,'/','F(X,t) pour la rotation'],[905,435;925,435])
add_line([sys,'/','F(X,t) pour la rotation'],[960,435;995,435])
add_line([sys,'/','F(X,t) pour la rotation'],[300,435;435,435])
add_line([sys,'/','F(X,t) pour la rotation'],[390,435;390,560;410,560])
add_line([sys,'/','F(X,t) pour la rotation'],[810,435;855,435])
add_line([sys,'/','F(X,t) pour la rotation'],[390,435;390,340;425,340])
add_line([sys,'/','F(X,t) pour la rotation'],[840,340;855,340])
add_line([sys,'/','F(X,t) pour la rotation'],[720,340;730,340])
add_line([sys,'/','F(X,t) pour la rotation'],[575,435;615,435])
add_line([sys,'/','F(X,t) pour la rotation'],[725,435;775,435])
add_line([sys,'/','F(X,t) pour la rotation'],[655,340;670,340])
add_line([sys,'/','F(X,t) pour la rotation'],[470,590;515,590])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,233,410,317])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[115,133,150,167])

add_block('built-in/Note',[sys,'/',['Sortie de ',13,'l''angle (z,Z)',13,'en degrs1']])
set_param([sys,'/',['Sortie de ',13,'l''angle (z,Z)',13,'en degrs1']],...
		'hide name',0,...
		'position',[1100,305,1105,310])

add_block('built-in/Note',[sys,'/',[' DETUMBLING + MISE EN SPIN+ANNULATION DU SPIN ',13,'CONFIGURATION DE LA ROUE',13,'( Mthode de Steyn )']])
set_param([sys,'/',[' DETUMBLING + MISE EN SPIN+ANNULATION DU SPIN ',13,'CONFIGURATION DE LA ROUE',13,'( Mthode de Steyn )']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',26)
set_param([sys,'/',[' DETUMBLING + MISE EN SPIN+ANNULATION DU SPIN ',13,'CONFIGURATION DE LA ROUE',13,'( Mthode de Steyn )']],...
		'position',[648,5,653,10])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[715,270,720,275])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[455,545,460,550])


%     Subsystem  'Extras24'.

new_system([sys,'/','Extras24'])
set_param([sys,'/','Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras24'],...
		'Mask Display','Voir la courbe\nangle entre X et x\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,180/pi*depointages(:,1));grid;figure(gcf)'')')


%     Finished composite block 'Extras24'.

set_param([sys,'/','Extras24'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[675,820,850,886])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Vrification\n\nq constante',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[490,820,665,886])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Vrification\n\nenergie constante',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[300,820,475,886])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Vrification\np2plusr2 constante\nrotation transverse',...
		'Mask Dialogue','eval(''plot(temps,p2plusr2);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,815,290,886])


%     Subsystem  'Extras22'.

new_system([sys,'/','Extras22'])
set_param([sys,'/','Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras22'],...
		'Mask Display','Voir les courbes\nangles de \nCardan en degrs \nen fin de rgulation')
set_param([sys,'/','Extras22'],...
		'Mask Dialogue','eval(''NN=length(q);N=fix(NN/2);plot(temps(N:NN),roulis(N:NN),''''y'''',temps(N:NN),tangage(N:NN),''''c'''',temps(N:NN),lacet(N:NN),''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras22'.

set_param([sys,'/','Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[335,690,545,771])


%     Subsystem  'Extras21'.

new_system([sys,'/','Extras21'])
set_param([sys,'/','Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras21'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nabsolues p, q, r (rd/s)\nen fin de rgulation')
set_param([sys,'/','Extras21'],...
		'Mask Dialogue','eval(''NN=length(q);N=fix(NN/2);plot(temps(N:NN),p(N:NN),''''y'''',temps(N:NN),q(N:NN),''''c'''',temps(N:NN),r(N:NN),''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras21'.

set_param([sys,'/','Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[335,595,545,676])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nabsolues\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,''''y'''',temps,q,''''c'''',temps,r,''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[110,665,315,736])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Couple roue\n\n(mN)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1065,670,1235,736])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Vitesse roue\n\n(Tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vitesse_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1065,595,1235,661])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir la courbe\nangle beta(B,y)\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,beta_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[110,745,315,806])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles de\nCardan (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,595,315,661])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMx',...
		'Mask Dialogue','eval(''plot(temps,Mx);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[575,600,845,661])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMy',...
		'Mask Dialogue','eval(''plot(temps,My);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,670,850,731])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMz',...
		'Mask Dialogue','eval(''plot(temps,Mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,735,850,796])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,595,1040,661])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Voir la courbe\nangle entre Y et y\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,angle_Y_y);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,820,1040,886])


%     Subsystem  'Extras23'.

new_system([sys,'/','Extras23'])
set_param([sys,'/','Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras23'],...
		'Mask Display','Voir la courbe\nangle entre Z et z\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,Ang_Z_z);grid;figure(gcf)'')')


%     Finished composite block 'Extras23'.

set_param([sys,'/','Extras23'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1055,815,1230,881])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nsatellite/XYZ (/s)',...
		'Mask Dialogue','eval(''plot(temps,omega_quat);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[870,740,1040,801])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[875,670,1045,736])

add_block('built-in/Note',[sys,'/',['Sortie de ',13,'l''angle (z,Z)',13,'en degrs']])
set_param([sys,'/',['Sortie de ',13,'l''angle (z,Z)',13,'en degrs']],...
		'position',[1160,220,1165,225])

add_block('built-in/Note',[sys,'/',['Sortie de ',13,'l''angle (y,y)',13,'en degrs ']])
set_param([sys,'/',['Sortie de ',13,'l''angle (y,y)',13,'en degrs ']],...
		'position',[1165,275,1170,280])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,44,1012,680])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=cyan\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1065,485,1250,566])


%     Subsystem  'Sorties'.

new_system([sys,'/','Sorties'])
set_param([sys,'/','Sorties'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE',13,'Arrt de la simulation sur une condition portant:',13,'Sur la vitesse angulaire de tangage',13,'Sur l''angle de tangage',13,'Sur le temps']])
set_param([sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE',13,'Arrt de la simulation sur une condition portant:',13,'Sur la vitesse angulaire de tangage',13,'Sur l''angle de tangage',13,'Sur le temps']],...
		'Font Name','Arial')
set_param([sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE',13,'Arrt de la simulation sur une condition portant:',13,'Sur la vitesse angulaire de tangage',13,'Sur l''angle de tangage',13,'Sur le temps']],...
		'Font Weight','bold')
set_param([sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE',13,'Arrt de la simulation sur une condition portant:',13,'Sur la vitesse angulaire de tangage',13,'Sur l''angle de tangage',13,'Sur le temps']],...
		'Font Size',20)
set_param([sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE',13,'Arrt de la simulation sur une condition portant:',13,'Sur la vitesse angulaire de tangage',13,'Sur l''angle de tangage',13,'Sur le temps']],...
		'position',[640,15,645,20])

add_block('built-in/Mux',[sys,'/','Sorties/Mux1'])
set_param([sys,'/','Sorties/Mux1'],...
		'inputs','3',...
		'position',[865,285,895,365])

add_block('built-in/Clock',[sys,'/','Sorties/Clock'])
set_param([sys,'/','Sorties/Clock'],...
		'position',[785,400,805,420])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace8'])
set_param([sys,'/','Sorties/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[845,400,915,420])

add_block('built-in/Demux',[sys,'/','Sorties/Demux'])
set_param([sys,'/','Sorties/Demux'],...
		'outputs','[3 4]',...
		'position',[295,409,345,576])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn1'])
set_param([sys,'/','Sorties/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[525,518,585,552])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace14'])
set_param([sys,'/','Sorties/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[790,560,860,580])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace12'])
set_param([sys,'/','Sorties/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[790,490,860,510])

add_block('built-in/Demux',[sys,'/','Sorties/Demux2'])
set_param([sys,'/','Sorties/Demux2'],...
		'outputs','3',...
		'position',[685,483,730,587])

add_block('built-in/Note',[sys,'/','Sorties/Quaternion Q'])
set_param([sys,'/','Sorties/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[425,505,430,510])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace7'])
set_param([sys,'/','Sorties/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[675,440,745,460])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn3'])
set_param([sys,'/','Sorties/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[570,431,650,469])

add_block('built-in/Fcn',[sys,'/','Sorties/Fcn'])
set_param([sys,'/','Sorties/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[545,395,585,415])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace9'])
set_param([sys,'/','Sorties/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusr2',...
		'buffer','points_trace',...
		'position',[630,395,700,415])

add_block('built-in/Note',[sys,'/',['Sorties/Entre de',13,'p q r Q']])
set_param([sys,'/',['Sorties/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[245,435,250,440])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace13'])
set_param([sys,'/','Sorties/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[790,525,860,545])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace10'])
set_param([sys,'/','Sorties/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[625,342,725,368])

add_block('built-in/Demux',[sys,'/','Sorties/Demux3'])
set_param([sys,'/','Sorties/Demux3'],...
		'outputs','3',...
		'position',[435,228,480,332])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[605,522,630,548])

add_block('built-in/Note',[sys,'/','Sorties/Vrification  rotation transversale'])
set_param([sys,'/','Sorties/Vrification  rotation transversale'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[630,365,635,370])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace15'])
set_param([sys,'/','Sorties/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[615,235,685,255])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs1']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs1']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[545,232,570,258])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs2']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs2']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[545,267,570,293])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs3']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs3']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[545,302,570,328])

add_block('built-in/Note',[sys,'/',['Sorties/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']])
set_param([sys,'/',['Sorties/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']],...
		'position',[785,235,790,240])

add_block('built-in/Note',[sys,'/','Sorties/Angles en degrs'])
set_param([sys,'/','Sorties/Angles en degrs'],...
		'position',[920,535,925,540])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace16'])
set_param([sys,'/','Sorties/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[615,270,685,290])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace17'])
set_param([sys,'/','Sorties/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[615,305,685,325])

add_block('built-in/Note',[sys,'/','Sorties/Energie'])
set_param([sys,'/','Sorties/Energie'],...
		'position',[705,600,710,605])


%     Subsystem  'Sorties/Stop'.

new_system([sys,'/','Sorties/Stop'])
set_param([sys,'/','Sorties/Stop'],'Location',[4,44,1268,968])

add_block('built-in/MATLAB Fcn',[sys,'/',['Sorties/Stop/fonction',13,'de calcul ',13,'des dpointages']])
set_param([sys,'/',['Sorties/Stop/fonction',13,'de calcul ',13,'des dpointages']],...
		'MATLAB Fcn','depoint(u)',...
		'Output Width','3',...
		'Mask Display','depoint.m',...
		'position',[135,391,240,429])

add_block('built-in/Demux',[sys,'/','Sorties/Stop/Demux1'])
set_param([sys,'/','Sorties/Stop/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[270,379,320,441])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace19'])
set_param([sys,'/','Sorties/Stop/To Workspace19'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','Ang_Z_z',...
		'buffer','points_trace',...
		'position',[515,455,585,475])

add_block('built-in/Gain',[sys,'/','Sorties/Stop/Gain1'])
set_param([sys,'/','Sorties/Stop/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[365,416,395,444])

add_block('built-in/Note',[sys,'/','Sorties/Stop/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Sorties/Stop/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[580,760,585,765])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace21'])
set_param([sys,'/','Sorties/Stop/To Workspace21'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','depointages',...
		'buffer','points_trace',...
		'position',[100,492,225,518])

add_block('built-in/Outport',[sys,'/','Sorties/Stop/Outport'])
set_param([sys,'/','Sorties/Stop/Outport'],...
		'position',[1060,420,1080,440])

add_block('built-in/Note',[sys,'/',['Sorties/Stop/Sortie de l''angle',13,'(z,Z) en degrs']])
set_param([sys,'/',['Sorties/Stop/Sortie de l''angle',13,'(z,Z) en degrs']],...
		'position',[1070,455,1075,460])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace20'])
set_param([sys,'/','Sorties/Stop/To Workspace20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','angle_Y_y',...
		'buffer','points_trace',...
		'position',[515,480,585,500])

add_block('built-in/Outport',[sys,'/','Sorties/Stop/Outport1'])
set_param([sys,'/','Sorties/Stop/Outport1'],...
		'Port','2',...
		'position',[1060,510,1080,530])

add_block('built-in/MATLAB Fcn',[sys,'/',['Sorties/Stop/fonction ',13,'d''arrt2']])
set_param([sys,'/',['Sorties/Stop/fonction ',13,'d''arrt2']],...
		'MATLAB Fcn','(abs(u)<ecart_max_Y)',...
		'Output Width','1',...
		'Mask Display','ON_OFF',...
		'position',[440,558,530,592])

add_block('built-in/Note',[sys,'/',['Sorties/Stop/Sortie de l''angle',13,'(y,Y ) en degrs']])
set_param([sys,'/',['Sorties/Stop/Sortie de l''angle',13,'(y,Y ) en degrs']],...
		'position',[1070,550,1075,555])

add_block('built-in/Gain',[sys,'/','Sorties/Stop/Gain3'])
set_param([sys,'/','Sorties/Stop/Gain3'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[365,561,395,589])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace1'])
set_param([sys,'/','Sorties/Stop/To Workspace1'],...
		'hide name',0,...
		'mat-name','stopY',...
		'buffer','points_trace',...
		'position',[610,612,660,628])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace2'])
set_param([sys,'/','Sorties/Stop/To Workspace2'],...
		'hide name',0,...
		'mat-name','stopZ',...
		'buffer','points_trace',...
		'position',[600,332,650,348])

add_block('built-in/MATLAB Fcn',[sys,'/',['Sorties/Stop/fonction ',13,'d''arrt1']])
set_param([sys,'/',['Sorties/Stop/fonction ',13,'d''arrt1']],...
		'MATLAB Fcn','(abs(u)<ecart_max_Z)',...
		'Output Width','1',...
		'Mask Display','Ecart_max Z',...
		'position',[450,363,555,397])

add_block('built-in/Stop Simulation',[sys,'/','Sorties/Stop/Stop Simulation'])
set_param([sys,'/','Sorties/Stop/Stop Simulation'],...
		'position',[1065,283,1105,317])

add_block('built-in/Gain',[sys,'/','Sorties/Stop/Gain'])
set_param([sys,'/','Sorties/Stop/Gain'],...
		'BackGround',7,...
		'position',[895,283,975,317])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace'])
set_param([sys,'/','Sorties/Stop/To Workspace'],...
		'mat-name','stop',...
		'buffer','points_trace',...
		'position',[1060,247,1110,263])

add_block('built-in/Product',[sys,'/','Sorties/Stop/Product1'])
set_param([sys,'/','Sorties/Stop/Product1'],...
		'position',[660,450,685,505])

add_block('built-in/Inport',[sys,'/','Sorties/Stop/in_1'])
set_param([sys,'/','Sorties/Stop/in_1'],...
		'Port','2',...
		'position',[100,262,125,288])

add_block('built-in/To Workspace',[sys,'/','Sorties/Stop/To Workspace3'])
set_param([sys,'/','Sorties/Stop/To Workspace3'],...
		'hide name',0,...
		'mat-name','stopYZ',...
		'buffer','points_trace',...
		'position',[765,467,815,483])

add_block('built-in/Note',[sys,'/','Sorties/Stop/pqrQ'])
set_param([sys,'/','Sorties/Stop/pqrQ'],...
		'ForeGround',1,...
		'position',[60,395,65,400])

add_block('built-in/Note',[sys,'/',['Sorties/Stop/q',13,'teta',13,'temps']])
set_param([sys,'/',['Sorties/Stop/q',13,'teta',13,'temps']],...
		'ForeGround',1,...
		'position',[70,245,75,250])

add_block('built-in/Inport',[sys,'/','Sorties/Stop/in_2'])
set_param([sys,'/','Sorties/Stop/in_2'],...
		'position',[90,397,110,423])

add_block('built-in/MATLAB Fcn',[sys,'/',['Sorties/Stop/fonction ',13,'d''arrt']])
set_param([sys,'/',['Sorties/Stop/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','(abs(u(1)<=q_max))&(abs(u(2)<=tangage_max))&(u(3)>(temps_phase3+temps_stop))',...
		'Output Width','1',...
		'position',[270,253,370,297])

add_block('built-in/Product',[sys,'/','Sorties/Stop/Product'])
set_param([sys,'/','Sorties/Stop/Product'],...
		'position',[765,248,790,352])
add_line([sys,'/','Sorties/Stop'],[115,410;130,410])
add_line([sys,'/','Sorties/Stop'],[130,275;265,275])
add_line([sys,'/','Sorties/Stop'],[980,300;1060,300])
add_line([sys,'/','Sorties/Stop'],[990,300;990,255;1055,255])
add_line([sys,'/','Sorties/Stop'],[245,410;265,410])
add_line([sys,'/','Sorties/Stop'],[325,430;360,430])
add_line([sys,'/','Sorties/Stop'],[400,430;1055,430])
add_line([sys,'/','Sorties/Stop'],[425,430;425,380;445,380])
add_line([sys,'/','Sorties/Stop'],[425,430;425,465;510,465])
add_line([sys,'/','Sorties/Stop'],[795,300;890,300])
add_line([sys,'/','Sorties/Stop'],[245,410;245,505;230,505])
add_line([sys,'/','Sorties/Stop'],[325,410;350,410;360,575])
add_line([sys,'/','Sorties/Stop'],[400,575;435,575])
add_line([sys,'/','Sorties/Stop'],[410,575;410,520;1055,520])
add_line([sys,'/','Sorties/Stop'],[480,520;480,490;510,490])
add_line([sys,'/','Sorties/Stop'],[535,575;545,575;545,620;605,620])
add_line([sys,'/','Sorties/Stop'],[560,380;570,380;570,340;595,340])
add_line([sys,'/','Sorties/Stop'],[545,575;630,575;630,490;655,490])
add_line([sys,'/','Sorties/Stop'],[570,380;625,380;625,465;655,465])
add_line([sys,'/','Sorties/Stop'],[375,275;760,275])
add_line([sys,'/','Sorties/Stop'],[690,480;720,480;720,475;760,475])
add_line([sys,'/','Sorties/Stop'],[690,480;720,480;720,325;760,325])
set_param([sys,'/','Sorties/Stop'],...
		'Mask Display','STOP')


%     Finished composite block 'Sorties/Stop'.

set_param([sys,'/','Sorties/Stop'],...
		'ForeGround',5,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[965,282,1050,338])

add_block('built-in/Outport',[sys,'/','Sorties/Outport'])
set_param([sys,'/','Sorties/Outport'],...
		'hide name',0,...
		'position',[1120,285,1140,305])

add_block('built-in/Outport',[sys,'/','Sorties/Outport1'])
set_param([sys,'/','Sorties/Outport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[1120,315,1140,335])

add_block('built-in/Note',[sys,'/','Sorties/Q'])
set_param([sys,'/','Sorties/Q'],...
		'position',[555,655,560,660])

add_block('built-in/Note',[sys,'/','Sorties/Angle (Y,y)'])
set_param([sys,'/','Sorties/Angle (Y,y)'],...
		'position',[1175,310,1180,315])

add_block('built-in/Note',[sys,'/','Sorties/Angle (Z,z)'])
set_param([sys,'/','Sorties/Angle (Z,z)'],...
		'position',[1175,280,1180,285])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace11'])
set_param([sys,'/','Sorties/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[895,679,980,711])

add_block('built-in/Note',[sys,'/',['Sorties/Normalement ces 2 vecteurs',13,' sont identiques aux erreurs de calcul prs']])
set_param([sys,'/',['Sorties/Normalement ces 2 vecteurs',13,' sont identiques aux erreurs de calcul prs']],...
		'position',[1075,715,1080,720])

add_block('built-in/Note',[sys,'/','Sorties/ce qui est vrifi'])
set_param([sys,'/','Sorties/ce qui est vrifi'],...
		'position',[1075,750,1080,755])


%     Subsystem  'Sorties/Rotation // axes orbitaux'.

new_system([sys,'/','Sorties/Rotation // axes orbitaux'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux'],'Location',[228,316,1185,966])

add_block('built-in/Outport',[sys,'/','Sorties/Rotation // axes orbitaux/Outport'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Outport'],...
		'hide name',0,...
		'position',[830,265,850,285])

add_block('built-in/Note',[sys,'/','Sorties/Rotation // axes orbitaux/Drive de Q'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[445,300,450,305])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/Rotation // axes orbitaux/MATLAB Fcn4'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[625,256,705,294])

add_block('built-in/To Workspace',[sys,'/','Sorties/Rotation // axes orbitaux/To Workspace5'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[375,197,480,233])

add_block('built-in/Note',[sys,'/',['Sorties/Rotation // axes orbitaux/Q''']])
set_param([sys,'/',['Sorties/Rotation // axes orbitaux/Q''']],...
		'position',[520,305,525,310])

add_block('built-in/Note',[sys,'/','Sorties/Rotation // axes orbitaux/Q'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Q'],...
		'position',[515,225,520,230])

add_block('built-in/Demux',[sys,'/','Sorties/Rotation // axes orbitaux/Demux1'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Demux1'],...
		'outputs','[3 4]',...
		'position',[280,174,330,341])

add_block('built-in/Gain',[sys,'/',['Sorties/Rotation // axes orbitaux/Conversion',13,'rd // degrs4']])
set_param([sys,'/',['Sorties/Rotation // axes orbitaux/Conversion',13,'rd // degrs4']],...
		'Gain','180/pi',...
		'position',[755,262,780,288])

add_block('built-in/Mux',[sys,'/','Sorties/Rotation // axes orbitaux/Mux'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Mux'],...
		'inputs','[4 4]',...
		'position',[545,226,580,324])

add_block('built-in/Inport',[sys,'/','Sorties/Rotation // axes orbitaux/in_2'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/in_2'],...
		'Port','2',...
		'position',[155,250,175,270])

add_block('built-in/Note',[sys,'/',['Sorties/Rotation // axes orbitaux/Entre de la',13,'drive du vecteur d''tat']])
set_param([sys,'/',['Sorties/Rotation // axes orbitaux/Entre de la',13,'drive du vecteur d''tat']],...
		'position',[160,285,165,290])

add_block('built-in/Note',[sys,'/','Sorties/Rotation // axes orbitaux/Entre de Q'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/Entre de Q'],...
		'position',[175,95,180,100])

add_block('built-in/Inport',[sys,'/','Sorties/Rotation // axes orbitaux/in_1'])
set_param([sys,'/','Sorties/Rotation // axes orbitaux/in_1'],...
		'position',[155,130,175,150])

add_block('built-in/Note',[sys,'/',['Sorties/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']])
set_param([sys,'/',['Sorties/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['Sorties/Rotation // axes orbitaux/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite',13,'et en degrs']],...
		'position',[790,320,795,325])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[785,275;825,275])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[710,275;750,275])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[585,275;620,275])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[335,300;540,300])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[335,215;370,215])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[180,260;275,260])
add_line([sys,'/','Sorties/Rotation // axes orbitaux'],[180,140;485,140;485,250;540,250])
set_param([sys,'/','Sorties/Rotation // axes orbitaux'],...
		'Mask Display','CALCUL DE LA VITESSE\nDE ROTATION\nEN AXES ORBITAUX')


%     Finished composite block 'Sorties/Rotation // axes orbitaux'.

set_param([sys,'/','Sorties/Rotation // axes orbitaux'],...
		'ForeGround',1,...
		'BackGround',3,...
		'position',[605,665,825,720])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace19'])
set_param([sys,'/','Sorties/To Workspace19'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat1',...
		'buffer','points_trace',...
		'position',[900,809,985,841])

add_block('built-in/Note',[sys,'/',['Sorties/Calcul direct de la rotation par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Sorties/Calcul direct de la rotation par',13,'rapport aux axes orbitaux']],...
		'position',[275,825,280,830])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn5'])
set_param([sys,'/','Sorties/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omeg_orb(u)',...
		'Output Width','3',...
		'position',[485,806,565,844])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs ']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs ']],...
		'Gain','180/pi',...
		'position',[680,812,705,838])

add_block('built-in/Inport',[sys,'/','Sorties/in_2'])
set_param([sys,'/','Sorties/in_2'],...
		'Port','2',...
		'position',[370,695,390,715])

add_block('built-in/Note',[sys,'/',['Sorties/Entre de ',13,'la drive du vecteur d''tat']])
set_param([sys,'/',['Sorties/Entre de ',13,'la drive du vecteur d''tat']],...
		'position',[440,730,445,735])

add_block('built-in/Inport',[sys,'/','Sorties/in_1'])
set_param([sys,'/','Sorties/in_1'],...
		'position',[30,485,50,505])
add_line([sys,'/','Sorties'],[350,450;565,450])
add_line([sys,'/','Sorties'],[655,450;670,450])
add_line([sys,'/','Sorties'],[55,495;290,495])
add_line([sys,'/','Sorties'],[350,535;520,535])
add_line([sys,'/','Sorties'],[810,410;840,410])
add_line([sys,'/','Sorties'],[485,450;485,405;540,405])
add_line([sys,'/','Sorties'],[590,405;625,405])
add_line([sys,'/','Sorties'],[485,405;485,355;620,355])
add_line([sys,'/','Sorties'],[395,705;600,705])
add_line([sys,'/','Sorties'],[500,535;500,680;600,680])
add_line([sys,'/','Sorties'],[590,535;600,535])
add_line([sys,'/','Sorties'],[635,535;680,535])
add_line([sys,'/','Sorties'],[735,500;785,500])
add_line([sys,'/','Sorties'],[735,570;785,570])
add_line([sys,'/','Sorties'],[375,450;375,280;430,280])
add_line([sys,'/','Sorties'],[485,245;540,245])
add_line([sys,'/','Sorties'],[575,245;610,245])
add_line([sys,'/','Sorties'],[485,280;540,280])
add_line([sys,'/','Sorties'],[575,280;610,280])
add_line([sys,'/','Sorties'],[575,315;610,315])
add_line([sys,'/','Sorties'],[485,315;540,315])
add_line([sys,'/','Sorties'],[735,535;785,535])
add_line([sys,'/','Sorties'],[595,280;595,300;860,300])
add_line([sys,'/','Sorties'],[765,535;765,325;860,325])
add_line([sys,'/','Sorties'],[825,410;825,350;860,350])
add_line([sys,'/','Sorties'],[900,325;960,325])
add_line([sys,'/','Sorties'],[95,495;95,205;935,205;935,295;960,295])
add_line([sys,'/','Sorties'],[1055,295;1115,295])
add_line([sys,'/','Sorties'],[1055,325;1115,325])
add_line([sys,'/','Sorties'],[95,495;95,815;480,825])
add_line([sys,'/','Sorties'],[710,825;895,825])
add_line([sys,'/','Sorties'],[570,825;675,825])
add_line([sys,'/','Sorties'],[830,695;890,695])
set_param([sys,'/','Sorties'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Sorties'.

set_param([sys,'/','Sorties'],...
		'position',[840,206,1030,299])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Vgain','180.000000',...
		'Hgain','25000.000000',...
		'Vmax','360.000000',...
		'Hmax','50000.000000',...
		'Window',[209,0,1107,422],...
		'position',[1085,215,1115,245])


%     Subsystem  'Transmission  VF'.

new_system([sys,'/','Transmission  VF'])
set_param([sys,'/','Transmission  VF'],'Location',[95,510,526,784])
open_system([sys,'/','Transmission  VF'])

add_block('built-in/Note',[sys,'/',['Transmission  VF/Sortie des valeurs finales',13,'de pqrQ']])
set_param([sys,'/',['Transmission  VF/Sortie des valeurs finales',13,'de pqrQ']],...
		'position',[245,100,250,105])

add_block('built-in/To Workspace',[sys,'/','Transmission  VF/To Workspace18'])
set_param([sys,'/','Transmission  VF/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','init_sca_fin',...
		'buffer','1',...
		'position',[185,45,325,95])

add_block('built-in/To File',[sys,'/','Transmission  VF/To File'])
set_param([sys,'/','Transmission  VF/To File'],...
		'File name','InitFin.mat',...
		'Matrix name','init_sca_fin',...
		'position',[205,144,310,176])

add_block('built-in/Inport',[sys,'/','Transmission  VF/in_1'])
set_param([sys,'/','Transmission  VF/in_1'],...
		'position',[35,60,55,80])
add_line([sys,'/','Transmission  VF'],[60,70;180,70])
add_line([sys,'/','Transmission  VF'],[100,70;100,160;200,160])
set_param([sys,'/','Transmission  VF'],...
		'Mask Display','SORTIE DES VALEURS FINALES\n\nEN VUE DE LA REGULATION FINE\n\nSTOCKAGE SUR LE DISQUE')


%     Finished composite block 'Transmission  VF'.

set_param([sys,'/','Transmission  VF'],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[835,338,1075,432])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance stn5dat.m']])
set_param([sys,'/',['L''initialisation',13,' lance stn5dat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1155,430,1160,435])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''clear;clc;stn5dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[835,465,1050,551])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'hide name',0,...
		'Vgain','180.000000',...
		'Hgain','25000.000000',...
		'Vmax','360.000000',...
		'Hmax','50000.000000',...
		'Window',[191,226,1106,690])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[1085,260,1115,290])
add_line(sys,[785,350;805,350;805,505;95,505;95,420;175,420])
add_line(sys,[620,350;675,350])
add_line(sys,[415,275;550,275])
add_line(sys,[400,420;550,420])
add_line(sys,[805,350;805,230;835,230])
add_line(sys,[655,350;655,275;835,275])
add_line(sys,[95,420;95,275;180,275])
add_line(sys,[1035,230;1080,230])
add_line(sys,[1035,275;1080,275])
add_line(sys,[805,385;830,385])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
